@@ -40,6 +40,7 @@
 #include "base/parms.h"
 #include "base/sleep.h"
 #include "base/status_code_mgt.h"
+#include "base/tuned_sleep.h"
 
 #include "vcp/parse_capabilities.h"
 #include "vcp/vcp_feature_codes.h"
@@ -393,8 +394,10 @@ int main(int argc, char *argv[]) {
    }
 
    // configure tracing
-   if (parsed_cmd->flags & CMD_FLAG_TIMESTAMP_TRACE)         // timestamps on debug and trace messages?
-      dbgtrc_show_time = true;              // extern in core.h
+   if (parsed_cmd->flags & CMD_FLAG_TIMESTAMP_TRACE)     // timestamps on debug and trace messages?
+      dbgtrc_show_time = true;                           // extern in core.h
+   if (parsed_cmd->flags & CMD_FLAG_THREAD_ID_TRACE)     // timestamps on debug and trace messages?
+      dbgtrc_show_thread_id = true;                      // extern in core.h
    report_freed_exceptions = parsed_cmd->flags & CMD_FLAG_REPORT_FREED_EXCP;   // extern in core.h
    set_trace_levels(parsed_cmd->traced_groups);
    if (parsed_cmd->traced_functions) {
@@ -488,9 +491,6 @@ int main(int argc, char *argv[]) {
 #endif
    }
 
-   if (parsed_cmd->sleep_strategy >= 0)
-      set_sleep_strategy(parsed_cmd->sleep_strategy);
-
 #ifdef USE_USB
    // if ( !(parsed_cmd->flags & CMD_FLAG_ENABLE_USB)) {
       DDCA_Status rc = ddc_enable_usb_display_detection( parsed_cmd->flags & CMD_FLAG_ENABLE_USB );
@@ -503,6 +503,10 @@ int main(int argc, char *argv[]) {
       threshold = DISPLAY_CHECK_ASYNC_THRESHOLD;
    ddc_set_async_threshold(threshold);
 
+   if (parsed_cmd->sleep_multiplier != 0 && parsed_cmd->sleep_multiplier != 1) {
+      set_sleep_multiplier_factor(parsed_cmd->sleep_multiplier);
+   }
+
    main_rc = EXIT_SUCCESS;     // from now on assume success;
    DBGTRC(main_debug, TRACE_GROUP, "Initialization complete, process commands");
 
@@ -811,8 +815,14 @@ int main(int argc, char *argv[]) {
                      flags |= FSF_RW_ONLY;
                   if (parsed_cmd->flags & CMD_FLAG_RO_ONLY)
                      flags |= FSF_RO_ONLY;
-                  if (parsed_cmd->flags & CMD_FLAG_WO_ONLY)
+
+                  // this is nonsense, get do getvcp on a WO feature
+                  // should be caught by parser
+                  if (parsed_cmd->flags & CMD_FLAG_WO_ONLY) {
                      flags |= FSF_WO_ONLY;
+                     DBGMSG("Invalid: GETVCP for WO features");
+                     assert(false);
+                  }
                   // char * s0 = feature_set_flag_names(flags);
                   // DBGMSG("flags: 0x%04x - %s", flags, s0);
                   // free(s0);
