@@ -1,30 +1,12 @@
-/* query_sysenv.c
+/** @file query_sysenv.c
  *
- * <copyright>
- * Copyright (C) 2014-2017 Sanford Rockowitz <rockowitz@minsoft.com>
- *
- * Licensed under the GNU General Public License Version 2
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
- * </endcopyright>
- */
-
-/** \f
  *  Primary file for the ENVIRONMENT command
  */
 
+// Copyright (C) 2014-2018 Sanford Rockowitz <rockowitz@minsoft.com>
+// SPDX-License-Identifier: GPL-2.0-or-later
+
+
 /** \cond */
 #include <config.h>
 
@@ -121,6 +103,7 @@ static void report_endian(int depth) {
 static void query_base_env(Env_Accumulator * accum) {
    int d0 = 0;
    int d1 = d0+1;
+   int d2 = d0+2;
 
    rpt_vstring(d0, "ddcutil version: %s", BUILD_VERSION);
    rpt_nl();
@@ -166,6 +149,20 @@ static void query_base_env(Env_Accumulator * accum) {
    sysenv_rpt_file_first_line("/proc/cmdline", NULL, d0);
 
    if (get_output_level() >= DDCA_OL_VERBOSE) {
+      rpt_nl();
+      rpt_vstring(d0, "Compiler information:");
+      rpt_vstring(d1, "C standard: %ld", __STDC_VERSION__);
+#if defined(__GNUC__)
+      rpt_vstring(d1, "gcc compatible compiler:");
+      rpt_vstring(d2, "Compiler version: %d.%d.%d", __GNUC__, __GNUC_MINOR__, __GNUC_PATCHLEVEL__);
+// not detecting clang (11/2018)
+#if defined(__clang__)
+      rpt_vstring(d2, "Clang version: %s", __clang_version__);
+#endif
+#else
+      rpt_vstring(d1, "Not a gcc compatible compiler");
+#endif
+
       rpt_nl();
       rpt_vstring(d0,"Processor information as reported by lscpu:");
         bool ok = execute_shell_cmd_rpt("lscpu", 1);
@@ -345,6 +342,7 @@ static void query_using_i2cdetect(Byte_Value_Array i2c_device_numbers) {
    int d1 = 1;
 
    rpt_vstring(d0,"Examining I2C buses using i2cdetect... ");
+   sysenv_rpt_current_time(NULL, d1);
 
    if (bva_length(i2c_device_numbers) == 0) {
       rpt_vstring(d1, "No I2C buses found");
@@ -380,6 +378,7 @@ static void query_using_i2cdetect(Byte_Value_Array i2c_device_numbers) {
 static void probe_i2c_devices_using_udev() {
    char * subsys_name = "i2c-dev";
    rpt_vstring(0,"Probing I2C devices using udev, susbsystem %s...", subsys_name);
+   sysenv_rpt_current_time(NULL, 1);
    // probe_udev_subsystem() is in udev_util.c, which is only linked in if USE_USB
 
    // Detailed scan of I2C device information
@@ -565,6 +564,9 @@ void query_sysenv() {
    device_xref_init();
 
    Env_Accumulator * accumulator = env_accumulator_new();
+   DDCA_Output_Level output_level = get_output_level();
+   if (output_level >= DDCA_OL_VERBOSE)
+      sysenv_rpt_current_time(NULL, 1);
 
    rpt_nl();
    rpt_vstring(0,"*** Basic System Information ***");
@@ -626,7 +628,6 @@ void query_sysenv() {
    rpt_nl();
    query_sys_bus_i2c(accumulator);
 
-   DDCA_Output_Level output_level = get_output_level();
    if (output_level >= DDCA_OL_VERBOSE) {
       rpt_nl();
       query_proc_driver_nvidia();
