@@ -63,7 +63,7 @@
 #include "query_sysenv_drm.h"
 
 // Trace class for this file
-static Trace_Group TRACE_GROUP = TRC_ENV;
+static DDCA_Trace_Group TRACE_GROUP = DDCA_TRC_ENV;
 
 #ifdef REF  // local copy for reference
 #define DRM_BUS_PCI   0
@@ -206,7 +206,8 @@ static void probe_open_device_using_libdrm(int fd, int depth) {
    busid = drmGetBusid(fd);
    if (busid) {
       rpt_vstring(d1, "DRM Busid:  %s", busid);
-      // drmFreeBusid(busid);
+      // drmFreeBusid(busid);  // requires root
+      free(busid);
    }
    else {
       rpt_vstring(d1, "Error calling drmGetBusid().  errno=%s", linux_errno_desc(errno));
