@@ -3,7 +3,7 @@
  * Check I2C devices using directly coded I2C calls
  */
 
-// Copyright (C) 2014-2018 Sanford Rockowitz <rockowitz@minsoft.com>
+// Copyright (C) 2014-2019 Sanford Rockowitz <rockowitz@minsoft.com>
 // SPDX-License-Identifier: GPL-2.0-or-later
 
 /** \cond */
@@ -141,16 +141,11 @@ try_single_getvcp_call(
       goto bye;
    }
 
-   // printf("(%s) read() returned %s\n", __func__, hexstring(ddc_response_bytes+1, readct) );
-   if (debug) {
-      char * hs = hexstring(ddc_response_bytes+1, readct);
-      DBGMSF(debug, "read() returned %s", hs );
-      free(hs);
-      // hex_dump(ddc_response_bytes,1+rc);
-   }
+   DBGMSF(debug, "read() returned %s", hexstring_t(ddc_response_bytes+1, readct) );
+   // hex_dump(ddc_response_bytes,1+rc);
 
    if ( all_bytes_zero( ddc_response_bytes+1, readct) ) {
-      DBGMSF0(debug, "All bytes zero");
+      DBGMSF(debug, "All bytes zero");
       rc = DDCRC_READ_ALL_ZERO;
       goto bye;
    }
@@ -161,7 +156,7 @@ try_single_getvcp_call(
        ddc_data_length == 0          &&
        ddc_response_bytes[3] == 0xbe)     // 0xbe == checksum
    {
-      DBGMSF0(debug, "Received DDC null response");
+      DBGMSF(debug, "Received DDC null response");
       rc = DDCRC_NULL_RESPONSE;
       goto bye;
    }
@@ -233,7 +228,7 @@ bye:
  */
 void raw_scan_i2c_devices(Env_Accumulator * accum) {
    bool debug = false;
-   DBGMSF0(debug, "Starting");
+   DBGMSF(debug, "Starting");
 
    int depth = 0;
    int d1 = depth+1;
@@ -352,7 +347,7 @@ void raw_scan_i2c_devices(Env_Accumulator * accum) {
    i2c_force_slave_addr_flag = saved_i2c_force_slave_addr_flag;
    buffer_free(buf0, __func__);
 
-   DBGMSF0(debug, "Done" );
+   DBGMSF(debug, "Done" );
 }
 
 
