@@ -13,9 +13,10 @@
  * - debug and trace messages
  */
 
-// Copyright (C) 2014-2018 Sanford Rockowitz <rockowitz@minsoft.com>
+// Copyright (C) 2014-2019 Sanford Rockowitz <rockowitz@minsoft.com>
 // SPDX-License-Identifier: GPL-2.0-or-later
 
+#define GNU_SOURCE    // for syscall()
 
 //* \cond */
 #include <assert.h>
@@ -24,6 +25,10 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+
+#include <sys/types.h>
+#include <sys/syscall.h>
+#include <unistd.h>
 /** \endcond */
 
 #include "util/data_structures.h"
@@ -362,7 +367,8 @@ void show_output_level() {
  *
  */
 
-bool dbgtrc_show_time = false;    ///< include elapsed time in debug/trace output
+bool dbgtrc_show_time      = false;   ///< include elapsed time in debug/trace output
+bool dbgtrc_show_thread_id = false;   ///< include thread id in debug/trace output
 
 static
 Value_Name_Title_Table trace_group_table = {
@@ -379,6 +385,7 @@ Value_Name_Title_Table trace_group_table = {
       VNT(DDCA_TRC_UDF, "UDF"),
       VNT(DDCA_TRC_VCP, "VCP"),
       VNT(DDCA_TRC_DDCIO, "DDCIO"),
+      VNT(DDCA_TRC_SLEEP, "SLEEP"),
       VNT_END
 };
 const int trace_group_ct = ARRAY_SIZE(trace_group_table)-1;
@@ -492,10 +499,13 @@ bool is_traced_function(const char * funcname) {
  *  @return **true** if trace is enabled for all functions in the file, **false** if not
  */
 bool is_traced_file(const char * filename) {
-   char * bname = g_path_get_basename(filename);
-   bool result = (traced_file_table && gaux_string_ptr_array_find(traced_file_table, bname) >= 0);
-   // printf("(%s) filename=|%s|, bname=|%s|, returning: %s\n", __func__, filename, bname, bool_repr(result));
-   free(bname);
+   bool result = false;
+   if (filename) {
+      char * bname = g_path_get_basename(filename);
+      result = (traced_file_table && gaux_string_ptr_array_find(traced_file_table, bname) >= 0);
+      // printf("(%s) filename=|%s|, bname=|%s|, returning: %s\n", __func__, filename, bname, bool_repr(result));
+      free(bname);
+   }
    return result;
 }
 
@@ -696,8 +706,11 @@ bool ddcmsg(DDCA_Trace_Group  trace_group,
       va_list(args);
       va_start(args, format);
       vsnprintf(buffer, 200, format, args);
-      if (debug_or_trace)
-         f0printf(fout(), "(%s) DDC: %s\n", funcname, buffer);
+      if (debug_or_trace) {
+         // f0printf(fout(), "(%s) DDC: %s\n", funcname, buffer);
+         // use dbgtrc() for consistent handling of timestamp and thread id prefixes
+         dbgtrc(0xff, funcname, lineno, filename, "DDC: %s", buffer);
+      }
       else
          f0printf(fout(), "DDC: %s\n", buffer);
       fflush(fout());
@@ -794,47 +807,50 @@ void severemsg(
  */
 bool dbgtrc(
         DDCA_Trace_Group  trace_group,
-        const char * funcname,
-        const int    lineno,
-        const char * filename,
-        char *       format,
+        const char *      funcname,
+        const int         lineno,
+        const char *      filename,
+        char *            format,
         ...)
 {
-   static char * buffer = NULL;
-   static int    bufsz  = 200;     // initial value
-   static char * buf2   = NULL;
-
-   if (!buffer) {      // first call
-      buffer = calloc(bufsz,    sizeof(char));
-      buf2   = calloc(bufsz+60, sizeof(char));
-   }
-
    bool msg_emitted = false;
    if ( is_tracing(trace_group, filename, funcname) ) {
       va_list(args);
       va_start(args, format);
-      int ct = vsnprintf(buffer, bufsz, format, args);
+      char * buffer = g_strdup_vprintf(format, args);
       va_end(args);
-      if (ct >= bufsz) {   // if buffer too small, reallocate
-         free(buffer);
-         free(buf2);
+      // int    bufsz = strlen(buffer) + 1;
 
-         bufsz = ct+1;
-         buffer = calloc(bufsz, sizeof(char));
-         buf2   = calloc(bufsz+50, sizeof(char));
-         va_list(args);
-         va_start(args, format);
-         ct = vsnprintf(buffer, bufsz, format, args);
-         assert(ct < bufsz);
-         va_end(args);
+
+      // *** TEMP ***
+      // dbgtrc_show_time = true;
+      // dbgtrc_show_thread_id = true;
+
+      char  elapsed_prefix[15] = "";
+      if (dbgtrc_show_time)
+         g_snprintf(elapsed_prefix, 15, "[%s]", formatted_elapsed_time());
+
+      char thread_prefix[15] = "";
+      if (dbgtrc_show_thread_id) {
+         pid_t tid = syscall(SYS_gettid);
+         snprintf(thread_prefix, 15, "[%7jd]", (intmax_t) tid);  // is this proper format for pid_t
       }
 
-      if (dbgtrc_show_time)
-         snprintf(buf2, bufsz+60, "[%s](%s) %s\n", formatted_elapsed_time(), funcname, buffer);
-      else
-         snprintf(buf2, bufsz+60, "(%s) %s\n", funcname, buffer);
+
+      int    buf2sz =  15+15+4 + strlen(funcname) + strlen(buffer) + 10;
+      char * buf2  = calloc(buf2sz, sizeof(char));
+      g_snprintf(buf2, buf2sz, "%s%s(%-30s) %s\n",
+                               thread_prefix,
+                               elapsed_prefix,
+                               funcname, buffer);
+      assert( strlen(buf2) < buf2sz);
+
+
       f0puts(buf2, fout());    // no automatic terminating null
       fflush(fout());
+
+      free(buffer);
+      free(buf2);
       msg_emitted = true;
    }
 
