@@ -24,7 +24,6 @@
 #include "feature_sets.h"
 #include "vcp_version.h"
 
-
 typedef void * Global_Display_Lock;
 
 
@@ -206,6 +205,7 @@ typedef struct _display_ref {
 Display_Ref * create_bus_display_ref(int busno);
 Display_Ref * create_adl_display_ref(int iAdapterIndex, int iDisplayIndex);
 Display_Ref * create_usb_display_ref(int bus, int device, char * hiddev_devname);
+void          dbgrpt_dref_flags(Dref_Flags flags, int depth);
 void          dbgrpt_display_ref(Display_Ref * dref, int depth);
 char *        dref_short_name_t(Display_Ref * dref);
 char *        dref_repr_t(Display_Ref * dref);  // value valid until next call
@@ -226,19 +226,20 @@ bool dref_eq(Display_Ref* this, Display_Ref* that);
 typedef struct {
    char         marker[4];
    Display_Ref* dref;
-   int          fh;     // file handle if ddc_io_mode == DDC_IO_DEVI2C or USB_IO                           // added 7/2016
+   int          fd;     // Linux file descriptor if ddc_io_mode == DDC_IO_DEVI2C or USB_IO                           // added 7/2016
    char *       repr;
 } Display_Handle;
 
-Display_Handle * create_bus_display_handle_from_display_ref(int fh, Display_Ref * dref);
+Display_Handle * create_bus_display_handle_from_display_ref(int fd, Display_Ref * dref);
 Display_Handle * create_adl_display_handle_from_display_ref(Display_Ref * dref);
-Display_Handle * create_usb_display_handle_from_display_ref(int fh, Display_Ref * dref);
+Display_Handle * create_usb_display_handle_from_display_ref(int fd, Display_Ref * dref);
 void             dbgrpt_display_handle(Display_Handle * dh, const char * msg, int depth);
 char *           dh_repr(Display_Handle * dh);
 char *           dh_repr_t(Display_Handle * dh);
 void             free_display_handle(Display_Handle * dh);
 
 
+
 // *** Video_Card_Info ***
 
 #define VIDEO_CARD_INFO_MARKER "VIDC"
