@@ -66,6 +66,8 @@ static Status_Code_Counts * primary_error_code_counts;
 static Status_Code_Counts * retryable_error_code_counts;
 static GMutex               status_code_counts_mutex;
 static GMutex               global_stats_mutex;
+
+
 static bool                 debug_status_code_counts_mutex  = false;
 static bool                 debug_global_stats_mutex = false;
 static bool                 debug_sleep_stats_mutex = false;
@@ -502,11 +504,10 @@ const char * sleep_event_name(Sleep_Event_Type event_type) {
 
 static int sleep_event_cts_by_id[SLEEP_EVENT_ID_CT];
 static int total_sleep_event_ct = 0;
-static int sleep_strategy = 0;
+
 static GMutex sleep_stats_mutex;
 
 
-static
 void reset_sleep_event_counts() {
    bool debug = false || debug_sleep_stats_mutex;
    DBGMSF(debug, "Starting");
@@ -520,272 +521,23 @@ void reset_sleep_event_counts() {
    DBGMSF(debug, "Done");
 }
 
-// TODO: create table of sleep strategy number, description
-
-
-/** Rudimentary mechanism for changing the sleep strategy.
- */
-bool set_sleep_strategy(int strategy) {
-   if (strategy == -1)    // if unset
-      strategy = 0;       // use default strategy
-   bool result = false;
-   if (strategy >= 0 && strategy <= 2) {
-      sleep_strategy = strategy;
-      result = true;
-   }
-   return result;
-}
-
-
-/** Gets the current sleep strategy number
- */
-int get_sleep_strategy() {
-   return sleep_strategy;
-}
-
-
-/** Gets description of a sleep strategy.
- *
- * \param sleep_strategy sleep strategy number
- * \return description
- */
-char * sleep_strategy_desc(int sleep_strategy) {
-   char * result = NULL;
-   switch(sleep_strategy) {
-   case (0):
-      result = "Default";
-      break;
-   case (1):
-      result = "Half sleep time";
-      break;
-   case (2):
-      result = "Double sleep time";
-      break;
-   default:
-      result = NULL;
-   }
-   return result;
-}
-
-
-/** Sleep for a period based on a failure event type and the number
- *  of consecutive failures.
- *
- *  This function does 3 things:
- *  1. Determines the sleep period based on the communication
- *     mechanism, event type and occurrence number.
- *  2. Records the sleep event.
- *  3. Sleeps for period determined.
- *
- * @param io_mode     communication mechanism (must be #DDCA_IO_I2C)
- * @param event_type  reason for sleep (currently only #SE_DDC_NULL - DDC Null Response)
- * @param occno       occurrence count of event
- *
- * @remark
- * Can be called in a multi-threaded environment.  Guards changes to the stats
- * data structure with a mutex.
- */
-void
-call_dynamic_tuned_sleep(
-      DDCA_IO_Mode io_mode,
-      Sleep_Event_Type event_type,
-      int occno)
-{
-   bool debug =  false || debug_sleep_stats_mutex;
-
-   int sleep_time_millis = 0;
-   assert(io_mode == DDCA_IO_I2C);
-   assert(event_type == SE_DDC_NULL);
-
-   switch(event_type) {
-   case SE_DDC_NULL:
-      sleep_time_millis = occno * DDC_TIMEOUT_MILLIS_NULL_RESPONSE_INCREMENT;
-      break;
-
-   default:
-      // PROGRAM_LOGIC_ERROR("Invalid sleep event type: %d = %s", event_type, sleep_event_name(event_type));
-      DBGMSG("PROGRAM LOCIG ERROR: Invalid sleep event type: %d = %s", event_type, sleep_event_name(event_type));
-   }
-
-   DBGMSF(debug, "Event type=%s, occno=%d, calculated sleep time = %d millisec",
-                 sleep_event_name(event_type), occno, sleep_time_millis);
-
-   g_mutex_lock(&sleep_stats_mutex);
-   sleep_event_cts_by_id[event_type]++;
-   total_sleep_event_ct++;
-   g_mutex_unlock(&sleep_stats_mutex);
-
-   sleep_millis(sleep_time_millis);
-
-   DBGMSF(debug, "Done");
-}
-
-
-/** Convenience function for invoking #call_dynamic_tuned_sleep() in
- *  the common case where the communication mechanism is I2C.
- *
- *  \param event_type
- *  \param occno occurrence count of event
- */
-void
-call_dynamic_tuned_sleep_i2c(
-      Sleep_Event_Type event_type,
-      int occno)
-{
-   call_dynamic_tuned_sleep(DDCA_IO_I2C, event_type, occno);
-}
-
-
-/** Sleep for a period required by the DDC protocol.
- *
- *  This function allows for tuning the actual sleep time.
- *
- *  This function does 3 things:
- *  1.  Determine the sleep period based on the communication
- *      mechanism, call type, sleep strategy in effect,
- *      and potentially other information.
- *  2. Record the sleep event.
- *  3. Sleep for period determined.
- *
- * @param io_mode     communication mechanism
- * @param event_type  reason for sleep
- *
- * @todo
- * Extend to take account of actual time since return from
- * last system call, previous error rate, etc.
- */
-void call_tuned_sleep(DDCA_IO_Mode io_mode, Sleep_Event_Type event_type) {
-   bool debug = false || debug_sleep_stats_mutex;
-   DBGMSF(debug, "Starting");
-
-   assert(event_type != SE_DDC_NULL);  // SE_DDC_NULL uses call_dynamic_tuned_sleep()
-
-   int sleep_time_millis = 0;    // should be a default
-   switch(io_mode) {
-
-   case DDCA_IO_I2C:
-      switch(event_type) {
-      case (SE_WRITE_TO_READ):
-            sleep_time_millis = DDC_TIMEOUT_MILLIS_DEFAULT;
-            switch(sleep_strategy) {
-            case (1):
-               sleep_time_millis = sleep_time_millis/2;
-               break;
-            case (2):
-               sleep_time_millis = sleep_time_millis*2;
-               break;
-            default:
-               break;
-            }
-            break;
-      case (SE_POST_WRITE):
-            sleep_time_millis = DDC_TIMEOUT_MILLIS_DEFAULT;
-            switch(sleep_strategy) {
-            case (1):
-               sleep_time_millis = sleep_time_millis/2;
-               break;
-            case (2):
-               sleep_time_millis = sleep_time_millis*2;
-               break;
-            default:
-               break;
-            }
-            break;
-      case (SE_POST_OPEN):
-            sleep_time_millis = DDC_TIMEOUT_MILLIS_DEFAULT;
-            break;
-      case (SE_POST_READ):
-            sleep_time_millis = DDC_TIMEOUT_MILLIS_DEFAULT;
-            break;
-      case (SE_POST_SAVE_SETTINGS):
-            sleep_time_millis = DDC_TIMEOUT_POST_SAVE_SETTINGS;   // per DDC spec
-            break;
-      default:
-         sleep_time_millis = DDC_TIMEOUT_MILLIS_DEFAULT;
-      }  // switch within DDC_IO_DEVI2C
-      break;
-
-   case DDCA_IO_ADL:
-      switch(event_type) {
-      case (SE_WRITE_TO_READ):
-            sleep_time_millis = DDC_TIMEOUT_MILLIS_DEFAULT;
-            break;
-      case (SE_POST_WRITE):
-            sleep_time_millis = DDC_TIMEOUT_MILLIS_DEFAULT;
-            break;
-      case (SE_POST_OPEN):
-            sleep_time_millis = DDC_TIMEOUT_MILLIS_DEFAULT;
-            break;
-      case (SE_POST_SAVE_SETTINGS):
-            sleep_time_millis = 200;   // per DDC spec
-            break;
-      default:
-         sleep_time_millis = DDC_TIMEOUT_MILLIS_DEFAULT;
-      }
-      break;
-
-   case DDCA_IO_USB:
-      PROGRAM_LOGIC_ERROR("call_tuned_sleep() called for USB_IO\n");
-      break;
-
-   }
-
-   // TODO:
-   //   get error rate (total calls, total errors), current adjustment value
-   //   adjust by time since last i2c event
-   // Is tracing useful, given that we know the event type?
-   // void sleep_millis_with_trace(int milliseconds, const char * caller_location, const char * message);
-
+void record_sleep_event(Sleep_Event_Type event_type) {
    // For better performance, separate mutex for each index in array
    g_mutex_lock(&sleep_stats_mutex);
    sleep_event_cts_by_id[event_type]++;
    total_sleep_event_ct++;
    g_mutex_unlock(&sleep_stats_mutex);
-
-   sleep_millis(sleep_time_millis);
-
-   DBGMSF(debug, "Done");
 }
 
 
-// Convenience functions
 
-/** Convenience function that invokes call_tuned_sleep() for
- *  /dev/i2c devices.
- *
- *  @param event_type sleep event type
- */
-void call_tuned_sleep_i2c(Sleep_Event_Type event_type) {
-   call_tuned_sleep(DDCA_IO_I2C, event_type);
-}
-
-
-/** Convenience function that invokes call_tuned_sleep() for
- *  ADL devices.
- *
- *  @param event_type sleep event type
- */
-void call_tuned_sleep_adl(Sleep_Event_Type event_type) {
-   call_tuned_sleep(DDCA_IO_ADL, event_type);
-}
-
-/** Convenience function that determines the device type from the
- *  #Display_Handle before invoking all_tuned_sleep().
- *  @param dh         display handle of open device
- *  @param event_type sleep event type
- */
-void call_tuned_sleep_dh(Display_Handle* dh, Sleep_Event_Type event_type) {
-   call_tuned_sleep(dh->dref->io_path.io_mode, event_type);
-}
-
-
-/** Reports sleep strategy statistics.
+/** Reports execution statistics.
  *
  * @param depth logical indentation depth
  */
-void report_sleep_strategy_stats(int depth) {
+void report_execution_stats(int depth) {
    int d1 = depth+1;
-   rpt_title("Sleep Strategy Stats:", depth);
+   rpt_title("IO and Sleep Events:", depth);
    rpt_vstring(d1, "Total IO events:      %5d", total_io_event_count());
    rpt_vstring(d1, "IO error count:       %5d", get_true_io_error_count(primary_error_code_counts));
    rpt_vstring(d1, "Total sleep events:   %5d", total_sleep_event_ct);
