@@ -1,30 +1,11 @@
-/* vcp_version.c
+/** @file vcp_version.c
  *
- * <copyright>
- * Copyright (C) 2014-2018 Sanford Rockowitz <rockowitz@minsoft.com>
- *
- * Licensed under the GNU General Public License Version 2
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
- * </endcopyright>
+ *  VCP (aka MCCS) version specification
  */
 
-/** \file
- * VCP/MCCS Version Specification
- *
- */
+// Copyright (C) 2014-2019 Sanford Rockowitz <rockowitz@minsoft.com>
+// SPDX-License-Identifier: GPL-2.0-or-later
+
 
 /** \cond */
 #include <assert.h>
@@ -90,7 +71,6 @@ bool vcp_version_is_valid(DDCA_MCCS_Version_Spec vspec, bool allow_unknown) {
 *
 */
 
-
 /** Checks if one #DDCA_MCCS_Version_Spec is less than or equal
  *  to another.
  *
@@ -152,6 +132,8 @@ bool vcp_version_eq(DDCA_MCCS_Version_Spec v1,  DDCA_MCCS_Version_Spec v2){
 }
 
 
+// use    if (vcp_version_eq(vspec, DDCA_VSPEC_UNQUERIED))
+#ifdef DEPRECATED
 /** Tests if a #DDCA_MCCS_Version_Spec represents "unqueried".
  *
  *  Encapsulates the use of a magic number.
@@ -162,6 +144,7 @@ bool vcp_version_eq(DDCA_MCCS_Version_Spec v1,  DDCA_MCCS_Version_Spec v2){
 bool vcp_version_is_unqueried(DDCA_MCCS_Version_Spec vspec) {
    return (vspec.major == 0xff && vspec.minor == 0xff);
 }
+#endif
 
 
 /** Converts a #DDCA_MCCS_Version_Spec to a printable string,
@@ -187,8 +170,6 @@ char * format_vspec(DDCA_MCCS_Version_Spec vspec) {
 }
 
 
-// new way:
-
 Value_Name_Title_Table version_id_table = {
       VNT(DDCA_MCCS_V10,   "1.0"),
       VNT(DDCA_MCCS_V20,   "2.0"),
@@ -200,8 +181,7 @@ Value_Name_Title_Table version_id_table = {
 };
 
 
-
-/** Returns a #DDCA_MCCS_Version_Id in a form suitable for display,
+/** Converts a #DDCA_MCCS_Version_Id to a humanly readable form,
  *  e.g. "2.0".
  *
  * @param version_id version id value
@@ -223,29 +203,12 @@ char * format_vcp_version_id(DDCA_MCCS_Version_Id version_id) {
    return result;
 }
 
-#ifdef OLD
-char * vcp_version_id_name0(DDCA_MCCS_Version_Id version_id) {
-   bool debug = false;
-   DBGMSF(debug, "Starting. version_id=%d", version_id);
-
-   char * result = NULL;
-   switch (version_id) {
-   case DDCA_MCCS_V10:    result = "DDCA_V10";     break;
-   case DDCA_MCCS_V20:    result = "DDCA_V20";     break;
-   case DDCA_MCCS_V21:    result = "DDCA_V21";     break;
-   case DDCA_MCCS_V30:    result = "DDCA_V30";     break;
-   case DDCA_MCCS_V22:    result = "DDCA_V22";     break;
-   case DDCA_MCCS_VNONE:  result = "DDCA_VNONE";   break;
-   }
-
-   char * result2 = vnt_name(version_id_table, version_id);
-   assert(streq(result, result2));
-
-   DBGMSF(debug, "Returning: %s", result);
-   return result;
-}
-#endif
 
+/** Returns the symbolic name of a #DDCA_MCCS_Version_Id value.
+ *
+ * @param   version_id version id value
+ * @return  symbolic name, e.g. "DDCA_V20";
+ */
 char * vcp_version_id_name(DDCA_MCCS_Version_Id version_id) {
    bool debug = false;
    DBGMSF(debug, "Starting. version_id=%d", version_id);
@@ -330,6 +293,6 @@ DDCA_MCCS_Version_Spec mccs_version_id_to_spec(DDCA_MCCS_Version_Id id) {
    case DDCA_MCCS_V22:    vspec = DDCA_VSPEC_V22;     break;
    }
 
-   DBGMSF(debug, "Returning: %d.%d", debug, vspec.major, vspec.minor);
+   DBGMSF(debug, "Returning: %d.%d", vspec.major, vspec.minor);
    return vspec;
 }
