@@ -1,31 +1,11 @@
-/* cmd_parser_aux.h
+/** \file cmd_parser_aux.h
  *
- * Functions and strings that are independent of the parser
- * package used.
- *
- * <copyright>
- * Copyright (C) 2014-2016 Sanford Rockowitz <rockowitz@minsoft.com>
- *
- * Licensed under the GNU General Public License Version 2
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
- * </endcopyright>
+ *  Functions and strings that are independent of the parser package used.
  */
 
-// Command parsing functions that are independent of the specific parser
-// being used.
+// Copyright (C) 20014-2018 Sanford Rockowitz <rockowitz@minsoft.com>
+// SPDX-License-Identifier: GPL-2.0-or-later
+
 
 #ifndef CMD_PARSER_AUX_H_
 #define CMD_PARSER_AUX_H_
@@ -59,6 +39,8 @@ bool parse_feature_id_or_subset(char * val, int cmd_id, Feature_Set_Ref * fsref)
 
 bool validate_output_level(Parsed_Cmd* parsed_cmd);
 
+char * assemble_command_argument_help();
+
 extern char * commands_list_help;
 extern char * command_argument_help;
 extern char * monitor_selection_option_help;
