@@ -163,6 +163,7 @@ Parsed_Cmd * parse_command(int argc, char * argv[]) {
    gboolean show_unsupported_flag = false;
    gboolean version_flag   = false;
    gboolean timestamp_trace_flag = false;
+   gboolean thread_id_trace_flag = false;
    gboolean verify_flag    = false;
    gboolean noverify_flag  = false;
    gboolean nodetect_flag  = false;
@@ -190,9 +191,10 @@ Parsed_Cmd * parse_command(int argc, char * argv[]) {
    gint     hidwork        = -1;
    gint     dispwork       = -1;
    char *   maxtrywork      = NULL;
-   gint     sleep_strategy_work = -1;
+   gint     i1_work = -1;
    char *   failsim_fn_work = NULL;
    // gboolean enable_failsim_flag = false;
+   char *   sleep_multiplier_work = NULL;
 
    GOptionEntry option_entries[] = {
    //  long_name short flags option-type          gpointer           description                    arg description
@@ -223,6 +225,8 @@ Parsed_Cmd * parse_command(int argc, char * argv[]) {
                            G_OPTION_ARG_CALLBACK, output_arg_func,   "Show brief detail",                NULL},
       {"brief",   '\0', G_OPTION_FLAG_NO_ARG,
                            G_OPTION_ARG_CALLBACK, output_arg_func,   "Show brief detail",                NULL},
+
+      // feature selection filters
       {"show-unsupported",
                   'U',  0, G_OPTION_ARG_NONE,     &show_unsupported_flag, "Report unsupported features", NULL},
       {"notable", '\0', G_OPTION_FLAG_HIDDEN,
@@ -250,6 +254,8 @@ Parsed_Cmd * parse_command(int argc, char * argv[]) {
       {"udf",     '\0', 0, G_OPTION_ARG_NONE,     &enable_udf_flag,  "Enable user defined feature support", NULL},
       {"noudf",   '\0', G_OPTION_FLAG_REVERSE,
                            G_OPTION_ARG_NONE,     &enable_udf_flag,  "Disable user defined feature support", NULL},
+      {"sleep-multiplier", '\0', 0,
+                           G_OPTION_ARG_STRING,   &sleep_multiplier_work, "Multiplication factor for DDC sleeps", "number"},
 
       // debugging
       {"excp",    '\0', 0, G_OPTION_ARG_NONE,     &report_freed_excp_flag,  "Report freed exceptions", NULL},
@@ -257,16 +263,16 @@ Parsed_Cmd * parse_command(int argc, char * argv[]) {
 //    {"trace",   '\0', 0, G_OPTION_ARG_STRING,   &tracework,        "Trace classes",          "comma separated list" },
       {"trcfunc", '\0',0, G_OPTION_ARG_STRING_ARRAY, &trace_functions, "Trace functions",     "function name" },
       {"trcfile", '\0',0, G_OPTION_ARG_STRING_ARRAY, &trace_filenames,    "Trace files",     "file name" },
+
       {"timestamp",'\0',  0, G_OPTION_ARG_NONE,   &timestamp_trace_flag, "Prepend trace msgs with elapsed time",  NULL},
       {"ts",      '\0',   0, G_OPTION_ARG_NONE,   &timestamp_trace_flag, "Prepend trace msgs with elapsed time",  NULL},
-
+      {"thread-id",'\0',  0, G_OPTION_ARG_NONE,   &thread_id_trace_flag, "Prepend trace msgs with thread id",  NULL},
+      {"tid",     '\0',   0, G_OPTION_ARG_NONE,   &thread_id_trace_flag, "Prepend trace msgs with thread id",  NULL},
 
 //    {"myusage", '\0', 0, G_OPTION_ARG_NONE,     &myusage_flag,     "Show usage", NULL},
-//    {"myhelp", '\0', 0,  G_OPTION_ARG_NONE,     &myhelp_flag,      "Show usage", NULL},
-      {"sleep-strategy",
-                  'y', 0,  G_OPTION_ARG_INT,      &sleep_strategy_work, "Set sleep strategy", "strategy number" },
-      {"failsim", '\0', 0,
-                           G_OPTION_ARG_FILENAME, &failsim_fn_work, "Enable simulation", "control file name"},
+//    {"myhelp",  '\0', 0,  G_OPTION_ARG_NONE,     &myhelp_flag,      "Show usage", NULL},
+      {"i1",      '\0', 0,  G_OPTION_ARG_INT,      &i1_work, "special", "non-negative number" },
+      {"failsim", '\0', 0,  G_OPTION_ARG_FILENAME, &failsim_fn_work, "Enable simulation", "control file name"},
 
       // other
       {"version", 'V',  0, G_OPTION_ARG_NONE,     &version_flag,     "Show version information", NULL},
@@ -354,10 +360,11 @@ Parsed_Cmd * parse_command(int argc, char * argv[]) {
 
    parsed_cmd->output_level     = output_level;
    parsed_cmd->stats_types      = stats_work;
-   parsed_cmd->sleep_strategy   = sleep_strategy_work;
+   parsed_cmd->i1               = i1_work;
    SET_CMDFLAG(CMD_FLAG_DDCDATA,           ddc_flag);
    SET_CMDFLAG(CMD_FLAG_FORCE_SLAVE_ADDR,  force_slave_flag);
    SET_CMDFLAG(CMD_FLAG_TIMESTAMP_TRACE,   timestamp_trace_flag);
+   SET_CMDFLAG(CMD_FLAG_THREAD_ID_TRACE,   thread_id_trace_flag);
    SET_CMDFLAG(CMD_FLAG_VERIFY,            verify_flag || !noverify_flag);
    // if (verify_flag || !noverify_flag)
    //    parsed_cmd->flags |= CMD_FLAG_VERIFY;
@@ -566,6 +573,24 @@ Parsed_Cmd * parse_command(int argc, char * argv[]) {
       }
    }
 
+   if (sleep_multiplier_work) {
+      DBGMSF(debug, "sleep_multiplier_work = |%s|", sleep_multiplier_work);
+      float multiplier = 0.0f;
+      bool arg_ok = str_to_float(sleep_multiplier_work, &multiplier);
+      if (arg_ok) {
+         if (multiplier <= 0.0f)
+            arg_ok = false;
+      }
+
+      if (!arg_ok) {
+          fprintf(stderr, "Invalid sleep-multiplier: %s\n", sleep_multiplier_work );
+          ok = false;
+      }
+      else {
+         parsed_cmd->sleep_multiplier = multiplier;
+      }
+   }
+
 
 #ifdef COMMA_DELIMITED_TRACE
    if (tracework) {
