@@ -51,11 +51,12 @@ typedef enum {
    CMD_FLAG_ASYNC               = 0x0100,
    CMD_FLAG_REPORT_FREED_EXCP   = 0x0200,
    CMD_FLAG_NOTABLE             = 0x0400,
+   CMD_FLAG_THREAD_ID_TRACE     = 0x0800,
    CMD_FLAG_RW_ONLY           = 0x010000,
    CMD_FLAG_RO_ONLY           = 0x020000,
    CMD_FLAG_WO_ONLY           = 0x040000,
    CMD_FLAG_ENABLE_UDF        = 0x100000,
-   CMD_FLAG_ENABLE_USB             = 0x200000,
+   CMD_FLAG_ENABLE_USB        = 0x200000,
 } Parsed_Cmd_Flags;
 
 
@@ -70,13 +71,14 @@ struct {
    DDCA_Stats_Type     stats_types;
    char *              failsim_control_fn;
    Display_Identifier* pdid;
-   DDCA_Trace_Group         traced_groups;
+   DDCA_Trace_Group    traced_groups;
    gchar **            traced_files;
    gchar **            traced_functions;
    DDCA_Output_Level   output_level;
    int                 max_tries[3];
-   int                 sleep_strategy;
+   float               sleep_multiplier;
    uint32_t            flags;      // Parsed_Cmd_Flags
+   int                 i1;         // available for temporary use
 
    // which?
    DDCA_MCCS_Version_Spec mccs_vspec;
