@@ -223,7 +223,8 @@ bye:
       }
    }
 
-   DBGTRC(debug, TRACE_GROUP, "Returning: %s", bool_repr(communication_working));
+   DBGTRC(debug, TRACE_GROUP, "dh=%s, Returning: %s",
+                 dh_repr_t(dh), sbool(communication_working));
    return communication_working;
 }
 
@@ -235,6 +236,8 @@ bye:
  *  \return **true** if DDC communication with the display succeeded, **false** otherwise.
  */
 bool initial_checks_by_dref(Display_Ref * dref) {
+   bool debug = false;
+   DBGMSF(debug, "Starting. dref=%s", dref_repr_t(dref) );
    bool result = false;
    Display_Handle * dh = NULL;
    Public_Status_Code psc = 0;
@@ -245,16 +248,22 @@ bool initial_checks_by_dref(Display_Ref * dref) {
       ddc_close_display(dh);
    }
 
+   DBGMSF(debug, "Done. dref = %s, returning %s", dref_repr_t(dref), sbool(result) );
    return result;
 }
 
 
 // function to be run in thread
 void * threaded_initial_checks_by_dref(gpointer data) {
+   bool debug = false;
+
    Display_Ref * dref = data;
    assert(memcmp(dref->marker, DISPLAY_REF_MARKER, 4) == 0 );
+   DBGMSF(debug, "Starting. dref = %s", dref_repr_t(dref) );
+
    initial_checks_by_dref(dref);
    // g_thread_exit(NULL);
+   DBGMSF(debug, "Done. dref = %s, returning NULL", dref_repr_t(dref) );
    return NULL;
 }
 
@@ -429,27 +438,21 @@ ddc_report_display_by_dref(Display_Ref * dref, int depth) {
    if (output_level >= DDCA_OL_NORMAL) {
       if (!(dref->flags & DREF_DDC_COMMUNICATION_WORKING) ) {
          rpt_vstring(d1, "DDC communication failed");
+         char * msg = NULL;
+         if (dref->io_path.io_mode == DDCA_IO_I2C)
+         {
+             I2C_Bus_Info * curinfo = dref->detail;
+             if (curinfo->flags & I2C_BUS_EDP)
+                 msg = "This is an eDP laptop display. Laptop displays do not support DDC/CI.";
+             else if ( is_embedded_parsed_edid(dref->pedid) )
+                 msg = "This appears to be a laptop display. Laptop displays do not support DDC/CI.";
+         }
          if (output_level >= DDCA_OL_VERBOSE) {
-#ifdef OLD
-            if (streq(dref->pedid->model_name,   "Unspecified") &&
-                streq(dref->pedid->serial_ascii, "Unspecified") )
-            {
-               rpt_vstring(d1, "This appears to be a laptop display. Laptop displays do not support DDC/CI.");
-            }
-            else
-               rpt_vstring(d1, "Is DDC/CI enabled in the monitor's on-screen display?");
-#endif
-
-            char * msg = "Is DDC/CI enabled in the monitor's on-screen display?";
-            if (dref->io_path.io_mode == DDCA_IO_I2C) {
-               I2C_Bus_Info * curinfo = dref->detail;
-               if (curinfo->flags & I2C_BUS_EDP)
-                  msg = "This is a eDP laptop display. Laptop displays do not support DDC/CI.";
-               else if ( is_embedded_parsed_edid(dref->pedid) )
-                  msg = "This appears to be a laptop display. Laptop displays do not support DDC/CI.";
-               else
-                  msg = "Is DDC/CI enabled in the monitor's on-screen display?";
+            if (!msg) {
+               msg = "Is DDC/CI enabled in the monitor's on-screen display?";
             }
+         }
+         if (msg) {
             rpt_vstring(d1, msg);
          }
       }
@@ -568,7 +571,7 @@ void ddc_dbgrpt_display_ref(Display_Ref * dref, int depth) {
          rpt_vstring(d1, "USB device information: ");
          Usb_Monitor_Info * moninfo = dref->detail;
          assert(memcmp(moninfo->marker, USB_MONITOR_INFO_MARKER, 4) == 0);
-         report_usb_monitor_info(moninfo, d2);
+         dbgrpt_usb_monitor_info(moninfo, d2);
 #else
          PROGRAM_LOGIC_ERROR("Built without USB support");
 #endif
@@ -1040,10 +1043,15 @@ ddc_detect_all_displays() {
  */
 void
 ddc_ensure_displays_detected() {
+   bool debug = false;
+   DBGMSF(debug, "Starting.");
    if (!all_displays) {
       i2c_detect_buses();
       all_displays = ddc_detect_all_displays();
+
    }
+   DBGMSF(debug, "all_displays has %d displays", all_displays->len);
+
 }
 
 
