@@ -1,28 +1,10 @@
-/* ddc_displays.h
+/** @file ddc_displays.h
  *
- * <copyright>
- * Copyright (C) 2014-2017 Sanford Rockowitz <rockowitz@minsoft.com>
- *
- * Licensed under the GNU General Public License Version 2
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
- * </endcopyright>
+ *  Access displays, whether DDC, ADL, or USB
  */
 
-/** \file
- */
+// Copyright (C) 2014-2019 Sanford Rockowitz <rockowitz@minsoft.com>
+// SPDX-License-Identifier: GPL-2.0-or-later
 
 #ifndef DDC_DISPLAYS_H_
 #define DDC_DDC_DISPLAYS_H_
@@ -77,10 +59,19 @@ ddc_find_display_by_edid(
 void
 ddc_dbgrpt_display_ref(Display_Ref * drec, int depth);
 
-GPtrArray *
-ddc_detect_all_displays();
+// GPtrArray *
+// ddc_detect_all_displays();
 
 void
 ddc_ensure_displays_detected();
 
+bool
+ddc_displays_already_detected();
+
+DDCA_Status
+ddc_enable_usb_display_detection(bool onoff);
+
+bool
+ddc_is_usb_display_detection_enabled();
+
 #endif /* DDC_DISPLAYS_H_ */
