@@ -511,11 +511,18 @@ ddc_collect_raw_subset_values(
    bool debug = false;
    DBGMSF(debug, "Starting.  subset=%d  dh=%s", subset, dh_repr(dh) );
 
+   assert(subset == VCP_SUBSET_PROFILE);  // currently the only use of this function,
+                                          // will need to reconsider handling of Feature_Set_Flags if other
+                                          // uses arise
+
    Public_Status_Code psc = 0;
 
    // DDCA_MCCS_Version_Spec vcp_version = get_vcp_version_by_display_handle(dh);
    // DBGMSG("VCP version = %d.%d", vcp_version.major, vcp_version.minor);
 
+   Feature_Set_Flags flags = FSF_NOTABLE;
+   if (subset == VCP_SUBSET_PROFILE)
+      flags |= FSF_RW_ONLY;
    Dyn_Feature_Set * feature_set = dyn_create_feature_set2_dfm(
                                      subset,
                                      dh->dref,          // vcp_version,
@@ -832,6 +839,7 @@ bool hack42(VCP_Feature_Table_Entry * ventry) {
  * Returns:
  *    status code
  */
+// 11/2019: only call is from app_getvcp.c
 Public_Status_Code
 ddc_show_vcp_values(
         Display_Handle *    dh,
