@@ -32,7 +32,9 @@
 #include "base/displays.h"
 #include "base/execution_stats.h"
 #include "base/parms.h"
+#include "base/rtti.h"
 #include "base/status_code_mgt.h"
+#include "base/tuned_sleep.h"
 
 #include "i2c/i2c_bus_core.h"
 #include "i2c/i2c_do_io.h"
@@ -204,7 +206,7 @@ ddc_open_display(
 
    if (ddcrc == 0) {
       if (dref->io_path.io_mode != DDCA_IO_USB)
-         call_tuned_sleep_i2c(SE_POST_OPEN);
+         TUNED_SLEEP_WITH_TRACE(dref->io_path.io_mode, SE_POST_OPEN, NULL);
       dref->flags |= DREF_OPEN;
    }
    else {
@@ -244,13 +246,13 @@ ddc_close_display(Display_Handle * dh) {
    switch(dh->dref->io_path.io_mode) {
    case DDCA_IO_I2C:
       {
-         rc = i2c_close_bus(dh->fh, dh->dref->io_path.path.i2c_busno,  CALLOPT_NONE);    // return error if failure
+         rc = i2c_close_bus(dh->fd, dh->dref->io_path.path.i2c_busno,  CALLOPT_NONE);    // return error if failure
          if (rc != 0) {
             assert(rc < 0);
             DBGMSG("i2c_close_bus returned %d", rc);
             COUNT_STATUS_CODE(rc);
          }
-         dh->fh = -1;    // indicate invalid, in case we try to continue using dh
+         dh->fd = -1;    // indicate invalid, in case we try to continue using dh
          break;
       }
    case DDCA_IO_ADL:
@@ -259,13 +261,13 @@ ddc_close_display(Display_Handle * dh) {
    case DDCA_IO_USB:
 #ifdef USE_USB
       {
-         rc = usb_close_device(dh->fh, dh->dref->usb_hiddev_name, CALLOPT_NONE); // return error if failure
+         rc = usb_close_device(dh->fd, dh->dref->usb_hiddev_name, CALLOPT_NONE); // return error if failure
          if (rc != 0) {
             assert(rc < 0);
             DBGMSG("usb_close_device returned %d", rc);
             COUNT_STATUS_CODE(rc);
          }
-         dh->fh = -1;
+         dh->fd = -1;
          break;
       }
 #else
@@ -408,21 +410,23 @@ static DDCA_Status ddc_i2c_write_read_raw(
 
    Status_Errno_DDC rc =
          invoke_i2c_writer(
-                           dh->fh,
+                           dh->fd,
                            get_packet_len(request_packet_ptr)-1,
                            get_packet_start(request_packet_ptr)+1 );
    DBGMSF(debug, "invoke_i2c_writer() returned %d\n", rc);
    if (rc == 0) {
-      call_tuned_sleep_i2c(SE_WRITE_TO_READ);
+      TUNED_SLEEP_I2C_WITH_TRACE(SE_WRITE_TO_READ, NULL);
+      // tuned_sleep_i2c_with_trace(SE_WRITE_TO_READ, __func__, NULL);
 
       // ALTERNATIVE_THAT_DIDNT_WORK:
       // if (single_byte_reads)  // fails
-      //    rc = invoke_single_byte_i2c_reader(dh->fh, max_read_bytes, readbuf);
+      //    rc = invoke_single_byte_i2c_reader(dh->fd, max_read_bytes, readbuf);
       // else
 
-      rc = invoke_i2c_reader(dh->fh, max_read_bytes, readbuf);
+      rc = invoke_i2c_reader(dh->fd, max_read_bytes, readbuf);
       // try adding sleep to see if improves capabilities read for P2411H
-      call_tuned_sleep_i2c(SE_POST_READ);
+      // tuned_sleep_i2c_with_trace(SE_POST_READ, __func__, NULL);
+      TUNED_SLEEP_I2C_WITH_TRACE(SE_POST_READ, NULL);
 
       if (rc == 0 && all_bytes_zero(readbuf, max_read_bytes)) {
          DDCMSG(debug, "All zero response detected in %s", __func__);
@@ -484,7 +488,8 @@ static DDCA_Status ddc_adl_write_read_raw(
       DBGTRC(debug, TRACE_GROUP, "adl_ddc_write_only() returned gsc=%d\n", psc);
    }
    else {
-      call_tuned_sleep_adl(SE_WRITE_TO_READ);
+      // tuned_sleep(DDCA_IO_ADL, SE_WRITE_TO_READ);
+      TUNED_SLEEP_WITH_TRACE(DDCA_IO_ADL, SE_WRITE_TO_READ, NULL);
       psc = adlshim_ddc_read_only(
             dh,
             readbuf,
@@ -686,6 +691,9 @@ ddc_write_read_with_retry(
    assert(dh->dref->io_path.io_mode != DDCA_IO_USB);
    // show_backtrace(1);
 
+   if (debug)
+      dbgrpt_display_ref(dh->dref, 1);
+
    bool retry_null_response = !(dh->dref->flags & DREF_DDC_USES_NULL_RESPONSE_FOR_UNSUPPORTED);
 
    DDCA_Status  psc;
@@ -694,6 +702,9 @@ ddc_write_read_with_retry(
    int  ddcrc_read_all_zero_ct = 0;
    int  ddcrc_null_response_ct = 0;
    int  ddcrc_null_response_max = (retry_null_response) ? 3 : 0;
+   // ddcrc_null_response_max = 6;  // *** TEMP *** for testing
+   DBGMSF(debug, "retry_null_response = %s, ddcrc_null_response_max = %d",
+          sbool(retry_null_response), ddcrc_null_response_max);
    Error_Info * try_errors[MAX_MAX_TRIES];
 
    assert(max_write_read_exchange_tries > 0);   // to avoid clang warning
@@ -737,7 +748,8 @@ ddc_write_read_with_retry(
                if (retryable) {
                   if (ddcrc_null_response_ct == 1 && get_output_level() >= DDCA_OL_VERBOSE)
                      f0printf(fout(), "Extended delay as recovery from DDC Null Response...\n");
-                  call_dynamic_tuned_sleep_i2c(SE_DDC_NULL, ddcrc_null_response_ct);
+                  set_sleep_multiplier_ct(ddcrc_null_response_ct+1);
+                  // replaces: call_dynamic_tuned_sleep_i2c(SE_DDC_NULL, ddcrc_null_response_ct);
                }
             }
             // when is DDCRC_READ_ALL_ZERO actually an error vs the response of the monitor instead of NULL response?
@@ -782,10 +794,12 @@ ddc_write_read_with_retry(
          tryctr, psc, bool_repr(retryable));
    if (debug) {
       for (int ndx = 0; ndx < tryctr; ndx++) {
-         DBGMSG("try_errors[%d] = %p", ndx, try_errors[ndx]);
+         DBGMSG("try_errors[%d] = %s", ndx, errinfo_summary(try_errors[ndx]));
       }
    }
 
+   set_sleep_multiplier_ct(1);   // in case we changed it
+
    Error_Info * ddc_excp = NULL;
 
    if (psc < 0) {
@@ -813,7 +827,7 @@ ddc_write_read_with_retry(
 
    try_data_record_tries(write_read_stats_rec, psc, tryctr);
 
-   DBGTRC(debug, TRACE_GROUP, "Done.  Returning: %s", errinfo_summary(ddc_excp));
+   DBGTRC(debug, TRACE_GROUP, "Done.  Total Tries (tryctr): %d. Returning: %s", tryctr, errinfo_summary(ddc_excp));
    return ddc_excp;
 }
 
@@ -849,7 +863,8 @@ ddc_i2c_write_only(
          (request_packet_ptr->type == DDC_PACKET_TYPE_SAVE_CURRENT_SETTINGS )
             ? SE_POST_SAVE_SETTINGS
             : SE_POST_WRITE;
-   call_tuned_sleep_i2c(sleep_type);
+   // tuned_sleep_i2c_with_trace(sleep_type, __func__, NULL);
+   TUNED_SLEEP_I2C_WITH_TRACE(sleep_type, NULL);
    DBGTRC(debug, TRACE_GROUP, "Done. rc=%s", psc_desc(rc) );
    return rc;
 }
@@ -872,7 +887,7 @@ ddc_write_only(
    DDCA_Status psc = 0;
    assert(dh->dref->io_path.io_mode != DDCA_IO_USB);
    if (dh->dref->io_path.io_mode == DDCA_IO_I2C) {
-      psc = ddc_i2c_write_only(dh->fh, request_packet_ptr);
+      psc = ddc_i2c_write_only(dh->fd, request_packet_ptr);
    }
    else {
       psc = adlshim_ddc_write_only(
@@ -991,3 +1006,18 @@ ddc_write_only_with_retry(
    return ddc_excp;
 }
 
+
+static void
+init_ddc_packet_io_func_name_table() {
+#define ADD_FUNC(_NAME) rtti_func_name_table_add(_NAME, #_NAME);
+   ADD_FUNC(ddc_write_read_raw);
+   ADD_FUNC(ddc_write_read);
+   ADD_FUNC(ddc_write_read_with_retry);
+#undef ADD_FUNC
+}
+
+
+void
+init_ddc_packet_io() {
+   init_ddc_packet_io_func_name_table();
+}
