@@ -3,7 +3,7 @@
  * ddc layer initialization and configuration, statistics management
  */
 
-// Copyright (C) 2014-2018 Sanford Rockowitz <rockowitz@minsoft.com>
+// Copyright (C) 2014-2019 Sanford Rockowitz <rockowitz@minsoft.com>
 // SPDX-License-Identifier: GPL-2.0-or-later
 
 /** \cond */
@@ -26,9 +26,12 @@
 
 #include "adl/adl_shim.h"
 
+#include "usb/usb_displays.h"
+
 #include "ddc/ddc_display_lock.h"
 #include "ddc/ddc_multi_part_io.h"
 #include "ddc/ddc_packet_io.h"
+#include "ddc/ddc_vcp.h"
 
 #include "ddc/ddc_services.h"
 
@@ -82,7 +85,7 @@ void ddc_report_stats_main(DDCA_Stats_Type stats, int depth) {
    }
    if (stats & DDCA_STATS_CALLS) {
       rpt_nl();
-      report_sleep_strategy_stats(depth);
+      report_execution_stats(depth);
       rpt_nl();
       report_io_call_stats(depth);
       rpt_nl();
@@ -131,10 +134,17 @@ void init_ddc_services() {
    adl_debug = debug;      // turn on adl initialization tracing
    adlshim_initialize();
 
+   // usb
+   init_usb_displays();
+
    // ddc:
    ddc_reset_ddc_stats();
    init_vcp_feature_codes();
    init_dyn_feature_codes();    // must come after init_vcp_feature_codes()
-   // dbgrpt_func_name_table(1);
    init_ddc_display_lock();
+   init_ddc_packet_io();
+   init_ddc_multi_part_io();
+   init_ddc_vcp();
+
+   // dbgrpt_func_name_table(1);
 }
