@@ -24,6 +24,7 @@
 #include "base/ddc_errno.h"
 #include "base/ddc_packets.h"
 #include "base/displays.h"
+#include "base/rtti.h"
 #include "base/status_code_mgt.h"
 
 #include "i2c/i2c_bus_core.h"
@@ -407,7 +408,6 @@ ddc_set_vcp_value(
    return ddc_excp;
 }
 
-
 /** Possibly returns a mock value for a non-table feature
  *
  *  \param  feature_code  VCP Feature Code
@@ -485,7 +485,7 @@ ddc_get_nontable_vcp_value(
        Parsed_Nontable_Vcp_Response** ppInterpretedCode)
 {
    bool debug = false;
-   DBGTRC(debug, TRACE_GROUP, "Reading feature 0x%02x", feature_code);
+   DBGTRC(debug, TRACE_GROUP, "dh=%s, Reading feature 0x%02x", dh_repr_t(dh), feature_code);
 
    Public_Status_Code psc = 0;
    Error_Info * excp = NULL;
@@ -521,8 +521,9 @@ ddc_get_nontable_vcp_value(
         );
    assert( (!excp && response_packet_ptr) || (excp && !response_packet_ptr));
    if (debug || IS_TRACING() ) {
+      psc = ERRINFO_STATUS(excp);
       if (psc != 0)
-         DBGMSG("perform_ddc_write_read_with_retry() returned %s, reponse_packet_ptr=%p",
+         DBGMSG("ddc_write_read_with_retry() returned %s, reponse_packet_ptr=%p",
                 psc_desc(psc), response_packet_ptr);
    }
    // psc = (excp) ? excp->psc : 0;
@@ -543,11 +544,11 @@ ddc_get_nontable_vcp_value(
 
          if (!parsed_response->valid_response)  {
             psc = DDCRC_DDC_DATA;             // was DDCRC_INVALID_DATA
-            excp = errinfo_new(psc, __func__);
+            excp = errinfo_new(DDCRC_DDC_DATA, __func__);
          }
          else if (!parsed_response->supported_opcode) {
             psc = DDCRC_REPORTED_UNSUPPORTED;
-            excp = errinfo_new(psc, __func__);
+            excp = errinfo_new(DDCRC_REPORTED_UNSUPPORTED, __func__);
          }
 
          if (psc != 0) {
@@ -565,11 +566,14 @@ ddc_get_nontable_vcp_value(
    if (response_packet_ptr)
       free_ddc_packet(response_packet_ptr);
 
+   // DBGMSG("excp = %s", errinfo_summary(excp));
+   // DBGMSG("parsed_response = %p", parsed_response);
+
    assert( (!excp && parsed_response) || (excp && !parsed_response)); // needed to avoid clang warning
    if (debug || IS_TRACING() ) {
       if (excp) {
-         DBGMSG("Error reading feature x%02x.  Returning exception: ", feature_code);
-         errinfo_report(excp, 1);
+         DBGMSG("Error reading feature x%02x.  Returning exception: %s", feature_code, errinfo_summary(excp));
+         // errinfo_report(excp, 1);
          DBGMSG("Done");
       }
       else {
@@ -586,7 +590,6 @@ ddc_get_nontable_vcp_value(
    return excp;
 }
 
-
 /** Gets the value of a table feature in a newly allocated Buffer struct.
  *  It is the responsibility of the caller to free the Buffer.
  *
@@ -595,7 +598,8 @@ ddc_get_nontable_vcp_value(
  *  \param  pp_table_bytes  location at which to save address of newly allocated Buffer
  *  \return NULL if success, pointer to #Error_Info if failure
  */
-Error_Info * ddc_get_table_vcp_value(
+Error_Info *
+ddc_get_table_vcp_value(
        Display_Handle *       dh,
        Byte                   feature_code,
        Buffer**               pp_table_bytes)
@@ -617,7 +621,7 @@ Error_Info * ddc_get_table_vcp_value(
    psc = (ddc_excp) ? ddc_excp->status_code : 0;
    if (debug || psc != 0) {
       DBGTRC(debug, TRACE_GROUP,
-             "perform_ddc_write_read_with_retry() returned %s", psc_desc(psc));
+             "multi_part_read_with_retry() returned %s", psc_desc(psc));
    }
 
    if (psc == 0) {
@@ -627,6 +631,14 @@ Error_Info * ddc_get_table_vcp_value(
          dbgrpt_buffer(paccumulator, 1);
       }
    }
+   // lowest level at which this check can be done, multi_part_read_with_retry() doesn't
+   // know it's being called for table value
+   else if (ddc_excp->status_code == DDCRC_NULL_RESPONSE ||
+            ddc_excp->status_code == DDCRC_ALL_RESPONSES_NULL)
+   {
+      Error_Info * wrapped_exception = ddc_excp;
+      ddc_excp = errinfo_new_with_cause(DDCRC_DETERMINED_UNSUPPORTED, wrapped_exception, __func__);
+   }
 
    DBGTRC(debug, TRACE_GROUP,
           "Done. rc=%s, *pp_table_bytes=%p", psc_desc(psc), *pp_table_bytes);
@@ -655,8 +667,8 @@ ddc_get_vcp_value(
        DDCA_Any_Vcp_Value **  valrec_loc)
 {
    bool debug = false;
-   DBGTRC(debug, TRACE_GROUP, "Starting. Reading feature 0x%02x, dh=%s, dh->fh=%d",
-            feature_code, dh_repr_t(dh), dh->fh);
+   DBGTRC(debug, TRACE_GROUP, "Starting. Reading feature 0x%02x, dh=%s, dh->fd=%d",
+            feature_code, dh_repr_t(dh), dh->fd);
 
    Public_Status_Code psc = 0;
    Error_Info * ddc_excp = NULL;
@@ -745,3 +757,14 @@ ddc_get_vcp_value(
    return ddc_excp;
 }
 
+static void init_ddc_vcp_func_name_table() {
+#define ADD_FUNC(_NAME) rtti_func_name_table_add(_NAME, #_NAME);
+   ADD_FUNC(ddc_get_table_vcp_value);
+   ADD_FUNC(ddc_get_vcp_value);
+#undef ADD_FUNC
+}
+
+void init_ddc_vcp() {
+   init_ddc_vcp_func_name_table();
+}
+
