@@ -79,6 +79,12 @@ ddca_feature_list_id_name(
    case DDCA_SUBSET_UNSET:
       result = "VCP_SUBSET_NONE";
       break;
+   case DDCA_SUBSET_CAPABILITIES:
+      result = "VCP_SUBSET_CAPABILITIES";      // ???
+      break;
+   case DDCA_SUBSET_SCAN:
+      result = "VCP_SUBSET_SCAN";
+      break;
    }
    return result;
 }
@@ -194,6 +200,12 @@ ddca_get_feature_list_by_dref(
                case DDCA_SUBSET_UNSET:
                   subset = VCP_SUBSET_NONE;
                   break;
+               case DDCA_SUBSET_CAPABILITIES:
+                  subset = VCP_SUBSET_NONE;
+                  // Currently handled in ddcui
+                  DBGMSG("DDCA_SUBSET_CAPABILITIES -> VCP_SUBSET_NONE");
+               case DDCA_SUBSET_SCAN:
+                  subset = VCP_SUBSET_SCAN;
                }
                Feature_Set_Flags flags = 0x00;
                if (!include_table_features)
@@ -490,6 +502,8 @@ ddca_get_feature_metadata_by_dh(
          ddca_dh,
          {
                bool debug = false;
+               // if (feature_code == 0xca)
+               //    debug = true;
                DBGMSF(debug, "Starting.  feature_code=0x%02x, ddca_dh=%s, create_default_if_not_found=%s, metadata_loc=%p",
                              feature_code, ddca_dh_repr(ddca_dh), sbool(create_default_if_not_found), metadata_loc);
                if (debug)
@@ -760,6 +774,14 @@ ddca_get_simple_nc_feature_value_name_by_display(
    );
 }
 
+void
+ddca_dbgrpt_feature_metadata(
+      DDCA_Feature_Metadata * md,
+      int                     depth)
+{
+   dbgrpt_ddca_feature_metadata(md, depth);
+}
+
 
 //
 //  Dynamic
