@@ -233,6 +233,13 @@ bool
 ddca_is_verify_enabled(void);
 
 
+void
+ddca_set_global_sleep_multiplier(double multiplier);
+
+double
+ddca_get_global_sleep_multiplier();
+
+
 //
 // Output Redirection
 //
@@ -378,6 +385,9 @@ ddca_set_trace_groups(
 DDCA_Trace_Group
 ddca_trace_group_name_to_value(char * name);
 
+void
+ddca_set_trace_options(DDCA_Trace_Options  options);
+
 
 //
 // Statistics and Diagnostics
@@ -1097,6 +1107,16 @@ ddca_get_simple_nc_feature_value_name_by_table(
       uint8_t                     feature_value,
       char**                      value_name_loc);
 
+/** Outputs a debugging report of the \DDCA_Feature_Metadata data structure.
+ *
+ *  @param md    pointer to \DDCA_Feature_Metadata instance
+ *  @param depth logical indentation depth
+ */
+void
+ddca_dbgrpt_feature_metadata(
+      DDCA_Feature_Metadata * md,
+      int                     depth);
+
 
 //
 //  Miscellaneous Monitor Specific Functions
