@@ -13,6 +13,11 @@
 #ifndef DDCUTIL_TYPES_H_
 #define DDCUTIL_TYPES_H_
 
+#ifdef __cplusplus
+extern "C"
+{
+#endif
+
 /** \cond */
 #include <stdbool.h>
 #include <stdint.h>                // for uint8_t, unit16_t
@@ -139,12 +144,19 @@ typedef enum {
  DDCA_TRC_UDF  = 0x0100,        /**< user-defined, aka dynamic, features */
  DDCA_TRC_VCP  = 0x0200,        /**< VCP layer, feature definitions */
  DDCA_TRC_DDCIO = 0x0400,       /**< DDC IO functions */
+ DDCA_TRC_SLEEP = 0x0800,       /**< low level sleeps */
 
  DDCA_TRC_NONE = 0x0000,        /**< all tracing disabled    */
  DDCA_TRC_ALL  = 0xffff         /**< all tracing enabled     */
 } DDCA_Trace_Group;
 
 
+typedef enum {
+   DDCA_TRCOPT_TIMESTAMP = 0x00,
+   DDCA_TRCOPT_THREAD_ID = 0x02,
+} DDCA_Trace_Options;
+
+
 //
 // Performance statistics
 //
@@ -282,6 +294,7 @@ typedef struct {
    uint8_t bytes[32];
 } DDCA_Feature_List;
 
+extern const DDCA_Feature_List DDCA_EMPTY_FEATURE_LIST;
 
 /** Identifiers for publicly useful VCP feature subsets
  *
@@ -294,7 +307,9 @@ typedef enum {
    DDCA_SUBSET_KNOWN,          ///< All features defined in a MCCS spec
    DDCA_SUBSET_COLOR,          ///< Color related features
    DDCA_SUBSET_PROFILE,        ///< Features saved and restored by loadvcp/setvcp
-   DDCA_SUBSET_MFG             ///< Feature codes reserved for manufacturer use (0x0e..0xff)
+   DDCA_SUBSET_MFG,            ///< Feature codes reserved for manufacturer use (0x0e..0xff)
+   DDCA_SUBSET_CAPABILITIES,   ///< Feature codes specified in capabilities string
+   DDCA_SUBSET_SCAN            ///< All feature codes other than known write-only or table
 } DDCA_Feature_Subset_Id;
 
 
@@ -439,7 +454,7 @@ typedef
 struct {
    char                                  marker[4];      /**< always "FMET" */
    DDCA_Vcp_Feature_Code                 feature_code;   /**< VCP feature code */
-// DDCA_MCCS_Version_Spec                vspec;          /**< MCCS version    */
+   DDCA_MCCS_Version_Spec                vcp_version;    /**< MCCS version    */
    DDCA_Feature_Flags                    feature_flags;  /**< feature type description */
    DDCA_Feature_Value_Entry *            sl_values;      /**< valid when DDCA_SIMPLE_NC set */
    char *                                feature_name;   /**< feature name */
@@ -528,4 +543,8 @@ typedef struct {
 #define VALREC_CUR_VAL(valrec) ( valrec->val.c_nc.sh << 8 | valrec->val.c_nc.sl )
 #define VALREC_MAX_VAL(valrec) ( valrec->val.c_nc.mh << 8 | valrec->val.c_nc.ml )
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif /* DDCUTIL_TYPES_H_ */
