@@ -94,7 +94,7 @@ usb_get_usage_value_by_report_type_and_ucode(
 
       if (debug) {
          DBGMSG0("After hid_get_usage_value():");
-         report_hiddev_usage_ref(&uref, 1);
+         dbgrpt_hiddev_usage_ref(&uref, 1);
       }
       // printf("(%s) errsv=%d, gsc=%d\n", __func__, errsv, gsc);
       goto bye;
@@ -102,7 +102,7 @@ usb_get_usage_value_by_report_type_and_ucode(
    *curval = uref.value;
 
    if (debug)
-      report_hiddev_usage_ref(&uref, 1);
+      dbgrpt_hiddev_usage_ref(&uref, 1);
 
    struct hiddev_field_info finfo = {0};
    finfo.report_type = uref.report_type;
@@ -121,7 +121,7 @@ usb_get_usage_value_by_report_type_and_ucode(
    }
 
    if (debug)
-      report_hiddev_field_info(&finfo, 1);
+      dbgrpt_hiddev_field_info(&finfo, 1);
 
    // per spec, logical max/min bound the values in the report,
    // physical min/max bound the "real world" units
@@ -189,7 +189,7 @@ set_control_value(int fd,
    };
    if (debug) {
       DBGMSG0("Before HIDIOCSUSAGE");
-      report_hiddev_usage_ref(&uref, 1);
+      dbgrpt_hiddev_usage_ref(&uref, 1);
    }
    if ((rc=ioctl(fd, HIDIOCSUSAGE, &uref)) < 0) {
       result = -errno;
@@ -243,7 +243,7 @@ set_usage_value_by_report_type_and_ucode(
    };
    if (debug) {
       DBGMSG0("Before HIDIOCSUSAGE");
-      report_hiddev_usage_ref(&uref, 1);
+      dbgrpt_hiddev_usage_ref(&uref, 1);
    }
    if ((rc=ioctl(fd, HIDIOCSUSAGE, &uref)) < 0) {
       psc = -errno;
@@ -345,7 +345,7 @@ usb_get_usage_value_by_vcprec(
    uref->usage_index = vcprec->usage_index;
 #endif
    if (debug)
-      report_hiddev_usage_ref(uref, 1);
+      dbgrpt_hiddev_usage_ref(uref, 1);
 
    psc  = hiddev_get_usage_value(fd, uref, CALLOPT_ERR_MSG);
    // rc = ioctl(fd, HIDIOCGUSAGE, uref);  // Fills in usage value
@@ -462,10 +462,10 @@ usb_get_nontable_vcp_value(
    if (use_alt_method) {
       __u32 usage_code = 0x0082 << 16 | feature_code;
       psc = usb_get_usage_value_by_report_type_and_ucode(
-                  dh->fh, HID_REPORT_TYPE_FEATURE, usage_code, &maxval, &curval);
+                  dh->fd, HID_REPORT_TYPE_FEATURE, usage_code, &maxval, &curval);
       if (psc != 0)
          psc = usb_get_usage_value_by_report_type_and_ucode(
-                  dh->fh, HID_REPORT_TYPE_INPUT,   usage_code, &maxval, &curval);
+                  dh->fd, HID_REPORT_TYPE_INPUT,   usage_code, &maxval, &curval);
    }
    else {
       // find the field record
@@ -488,7 +488,7 @@ usb_get_nontable_vcp_value(
 
             if (vcprec->report_type == HID_REPORT_TYPE_OUTPUT)
                continue;
-            psc = usb_get_usage_value_by_vcprec(dh->fh,  vcprec, &maxval, &curval);
+            psc = usb_get_usage_value_by_vcprec(dh->fd,  vcprec, &maxval, &curval);
             DBGMSF(debug, "usb_get_usage() usage index: %d returned %d, maxval=%d, curval=%d",
                           vcprec->usage_index, psc, maxval, curval);
             if (psc == 0)
@@ -620,7 +620,7 @@ usb_set_nontable_vcp_value(
    if (use_alt) {
       __u32 usage_code = 0x0082 << 16 | feature_code;
       psc = set_usage_value_by_report_type_and_ucode(
-               dh->fh, HID_REPORT_TYPE_FEATURE, usage_code, new_value);
+               dh->fd, HID_REPORT_TYPE_FEATURE, usage_code, new_value);
       // if (gsc != 0)
       //    gsc = set_usage_value_by_report_type_and_ucode(dh->fh, HID_REPORT_TYPE_OUTPUT, usage_code, new_value);
       // if (gsc == modulate_rc(EINVAL, RR_ERRNO))
@@ -650,7 +650,7 @@ usb_set_nontable_vcp_value(
             if (vcprec->report_type == HID_REPORT_TYPE_INPUT)
                continue;
 
-            psc = usb_set_usage_value_by_vcprec(dh->fh,  vcprec, new_value);
+            psc = usb_set_usage_value_by_vcprec(dh->fd,  vcprec, new_value);
             DBGMSF(debug, "usb_set_usage() usage index: %d returned %s",
                           vcprec->usage_index, psc_desc(psc) );
             if (psc == 0)
