@@ -1,28 +1,9 @@
-/* libusb_util.c
- *
- * libusb is currently used only within query_sysenv.c
- *
- * <copyright>
- * Copyright (C) 2016 Sanford Rockowitz <rockowitz@minsoft.com>
- *
- * Licensed under the GNU General Public License Version 2
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
- * </endcopyright>
+/** @file libusb_util.c
  */
 
+// Copyright (C) 2016-2019 Sanford Rockowitz <rockowitz@minsoft.com>
+// SPDX-License-Identifier: GPL-2.0-or-later
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -184,10 +165,12 @@ static bool possible_monitor_interface_descriptor(
    if (debug)
       printf("(%s) Starting.\n", __func__);
 
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wdiscarded-qualifiers"
-   dpath.inter = inter;
-#pragma GCC diagnostic pop
+// #pragma GCC diagnostic push
+// #pragma GCC diagnostic ignored "-Wdiscarded-qualifiers"
+// This pragma is undefined on older versions of gcc, results in warnings
+// when building for older OS releases on OBS.  So just use a cast instead.
+   dpath.inter = (struct libusb_interface_descriptor *) inter;
+// #pragma GCC diagnostic pop
 
    bool result = false;
    if (inter->bInterfaceClass == LIBUSB_CLASS_HID) {
@@ -221,11 +204,11 @@ static bool possible_monitor_interface(
    if (debug)
       printf("(%s) Starting.\n", __func__);
 
-// apparently doesn't work on older versions of GCC
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wdiscarded-qualifiers"
-   dpath.interface = interface;
-#pragma GCC diagnostic pop
+// pragma doesn't work on older versions of GCC, so use cast
+// #pragma GCC diagnostic push
+// #pragma GCC diagnostic ignored "-Wdiscarded-qualifiers"
+   dpath.interface =  (struct libusb_interface *) interface;
+// #pragma GCC diagnostic pop
 
    bool result = false;
    int ndx;
@@ -255,10 +238,10 @@ static bool possible_monitor_config_descriptor(
 {
     bool result = false;
 
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wdiscarded-qualifiers"
-    dpath.config = config;
-#pragma GCC diagnostic pop
+// #pragma GCC diagnostic push
+// #pragma GCC diagnostic ignored "-Wdiscarded-qualifiers"
+    dpath.config = (struct libusb_config_descriptor *) config;
+// #pragma GCC diagnostic pop
 
     int ndx = 0;
     if (config->bNumInterfaces > 1) {
