@@ -1,30 +1,11 @@
-/* device_id_util.c
- *
- * <copyright>
- * Copyright (C) 2014-2018 Sanford Rockowitz <rockowitz@minsoft.com>
- *
- * Licensed under the GNU General Public License Version 2
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
- * </endcopyright>
- */
-
 /** @file device_id_util.c
  * Lookup PCI and USB device ids
  */
 
+// Copyright (C) 2014-2019 Sanford Rockowitz <rockowitz@minsoft.com>
+// SPDX-License-Identifier: GPL-2.0-or-later
+
+
 /** \cond */
 #include <assert.h>
 #include <ctype.h>
@@ -379,7 +360,7 @@ static  Multi_Level_Map * load_multi_level_segment(
       }
    }
 
-   *curpos = linendx;
+   *curpos = (int) linendx;
    return header;
 }
 
@@ -1026,8 +1007,9 @@ bool devid_ensure_initialized() {
    bool ok = (pci_vendors_mlm && usb_vendors_mlm);
 
    if (!ok) {
-      printf("(%s) Loading.  pci_vendors_mlm=%p, usb_vendors_mlm=%p\n",
-             __func__,  pci_vendors_mlm, usb_vendors_mlm);
+      if (debug)
+         printf("(%s) Loading.  pci_vendors_mlm=%p, usb_vendors_mlm=%p\n",
+                __func__,  pci_vendors_mlm, usb_vendors_mlm);
       load_id_file(ID_TYPE_PCI);
       load_id_file(ID_TYPE_USB);
       ok = true;
