@@ -1,33 +1,9 @@
-/* report_util.c
- *
- * Functions for creating messages in a stardardized format, with flexible
- * indentation.  It is particularly used for tracing data structures.
- *
- * This source file maintains state in static variables so is not thread safe.
- *
- * <copyright>
- * Copyright (C) 2014-2017 Sanford Rockowitz <rockowitz@minsoft.com>
- *
- * Licensed under the GNU General Public License Version 2
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
- * </endcopyright>
- */
-
 /** @file report_util.c
- * Report utility functions
+ *
+ * Functions for creating messages in a standardized format, with flexible
+ * indentation.
+ *
+ * The functions in this source file are thread safe.
  *
  * TODO: describe
  * - indentation depth
@@ -35,8 +11,12 @@
  * - destination stack
  */
 
+// Copyright (C) 2014-2018 Sanford Rockowitz <rockowitz@minsoft.com>
+// SPDX-License-Identifier: GPL-2.0-or-later
+
 /** \cond */
 #include <assert.h>
+#include <glib-2.0/glib.h>
 #include <stdarg.h>
 #include <stdbool.h>
 #include <stdio.h>
@@ -54,60 +34,119 @@
 
 #define DEFAULT_INDENT_SPACES_PER_DEPTH 3
 #define INDENT_SPACES_STACK_SIZE  16
+#define OUTPUT_DEST_STACK_SIZE 8
 
+#ifdef OLD
 static int indent_spaces_stack[INDENT_SPACES_STACK_SIZE];
 static int indent_spaces_stack_pos = -1;
 
-#define OUTPUT_DEST_STACK_SIZE 8
-
 static FILE* output_dest_stack[OUTPUT_DEST_STACK_SIZE];
 static int   output_dest_stack_pos = -1;
 
 // work around for fact that can't initialize the initial stack entry to stdout
 static FILE* alt_initial_output_dest = NULL;
 static bool  initial_output_dest_changed = false;
+#endif
+
+
+//* Thread specific state */
+typedef struct {
+   uint8_t indent_spaces_stack[INDENT_SPACES_STACK_SIZE];
+   int indent_spaces_stack_pos;    // initial  -1;
+
+   FILE* output_dest_stack[OUTPUT_DEST_STACK_SIZE];
+   int   output_dest_stack_pos;   // initial  -1;
+
+   // work around for fact that can't initialize the initial stack entry to stdout
+   FILE* alt_initial_output_dest;     // initial NULL;
+   bool  initial_output_dest_changed; // initial false;
+} Per_Thread_Settings;
+
+
+/** Returns a struct for maintaining thread-specific settings
+ *  @return thread-specific struct of global settings
+ */
+static Per_Thread_Settings *  get_thread_settings() {
+   static GPrivate per_thread_settings_key = G_PRIVATE_INIT(g_free);
+
+   Per_Thread_Settings* settings = g_private_get(&per_thread_settings_key);
+
+   // GThread * this_thread = g_thread_self();
+   // printf("(%s) this_thread=%p, settings=%p\n", __func__, this_thread, settings);
+
+   if (!settings) {
+      settings = g_new0(Per_Thread_Settings, 1);
+      settings->indent_spaces_stack_pos = -1;
+      settings->output_dest_stack_pos   = -1;
+
+      g_private_set(&per_thread_settings_key, settings);
+   }
+
+   // printf("(%s) Returning: %p\n", __func__, settings);
+   return settings;
+}
 
 
 //
 // Indentation
 //
 
-// Functions that allow for temporarily changing the number of
-// indentation spaces per logical indentation depth.
+// Functions that allow for temporarily changing the number of indentation
+// spaces per logical indentation depth on the current thread.
 // 10/16/15: not currently used
 
+/** Sets the spaces-per-indentation-depth to be used for report functions.
+ *  The current spaces-per-depth is saved on the thread-specific spaces-per-depth stack.
+ *
+ *  @param new_dest  new output destination
+ */
 void rpt_push_indent(int new_spaces_per_depth) {
-   assert(indent_spaces_stack_pos < INDENT_SPACES_STACK_SIZE-1);
-   indent_spaces_stack[++indent_spaces_stack_pos] = new_spaces_per_depth;
+   Per_Thread_Settings * settings = get_thread_settings();
+   assert(settings->indent_spaces_stack_pos < INDENT_SPACES_STACK_SIZE-1);
+   settings->indent_spaces_stack[++settings->indent_spaces_stack_pos] = new_spaces_per_depth;
 }
 
 
+/** Pops the space-per-indentation-depth stack.
+ *
+ *  @remark
+ *  No effect if stack is empty.
+ */
 void rpt_pop_indent() {
-   if (indent_spaces_stack_pos >= 0)
-      indent_spaces_stack_pos--;
+   Per_Thread_Settings * settings = get_thread_settings();
+   if (settings->indent_spaces_stack_pos >= 0)
+      settings->indent_spaces_stack_pos--;
 }
 
 
+/** Empties the space-per-indentation-depth stack.
+ *
+ *  The effect is to reset the per-thread spaces-per-indentation-depth
+ *  to its default value.
+ */
 void rpt_reset_indent_stack() {
-   indent_spaces_stack_pos = -1;
+   Per_Thread_Settings * settings = get_thread_settings();
+   settings->indent_spaces_stack_pos = -1;
 }
 
 
 /** Given a logical indentation depth, returns the number of spaces
- * of indentation to be used.
+ *  of indentation to be used.
  *
- * @param depth logical indentation depth
- * @return number of indentation spaces
+ *  @param depth logical indentation depth
+ *  @return number of indentation spaces
  */
 int rpt_get_indent(int depth) {
+   Per_Thread_Settings * settings = get_thread_settings();
    int spaces_ct = DEFAULT_INDENT_SPACES_PER_DEPTH;
-   if (indent_spaces_stack_pos >= 0)
-      spaces_ct = indent_spaces_stack[indent_spaces_stack_pos];
+   if (settings->indent_spaces_stack_pos >= 0)
+      spaces_ct = settings->indent_spaces_stack[settings->indent_spaces_stack_pos];
    return depth * spaces_ct;
 }
 
 
-// Functions that allow for temporarily changing the output destination.
+// Functions that allow for temporarily changing the output destination
+// on the current thread.
 
 /** Sets the output destination to be used for report functions.
  *  The current output destination is saved on the output destination stack.
@@ -115,8 +154,9 @@ int rpt_get_indent(int depth) {
  *  @param new_dest  new output destination
  */
 void rpt_push_output_dest(FILE* new_dest) {
-   assert(output_dest_stack_pos < OUTPUT_DEST_STACK_SIZE-1);
-   output_dest_stack[++output_dest_stack_pos] = new_dest;
+   Per_Thread_Settings * settings = get_thread_settings();
+   assert(settings->output_dest_stack_pos < OUTPUT_DEST_STACK_SIZE-1);
+   settings->output_dest_stack[++settings->output_dest_stack_pos] = new_dest;
 }
 
 
@@ -124,8 +164,9 @@ void rpt_push_output_dest(FILE* new_dest) {
  *  to be used for report functions to the new top of the stack.
  */
 void rpt_pop_output_dest() {
-   if (output_dest_stack_pos >= 0)
-      output_dest_stack_pos--;
+   Per_Thread_Settings * settings = get_thread_settings();
+   if (settings->output_dest_stack_pos >= 0)
+      settings->output_dest_stack_pos--;
 }
 
 
@@ -133,7 +174,8 @@ void rpt_pop_output_dest() {
  * The output destination to be used for report functions to the default (stdout).
  */
 void rpt_reset_output_dest_stack() {
-   output_dest_stack_pos = -1;
+   Per_Thread_Settings * settings = get_thread_settings();
+   settings->output_dest_stack_pos = -1;
 }
 
 
@@ -142,13 +184,14 @@ void rpt_reset_output_dest_stack() {
  * @return current output destination
  */
 FILE * rpt_cur_output_dest() {
+   Per_Thread_Settings * settings = get_thread_settings();
    // special handling for unpushed case because can't statically initialize
    // output_dest_stack[0] to stdout
    FILE * result = NULL;
-   if (output_dest_stack_pos < 0)
-      result = (initial_output_dest_changed) ? alt_initial_output_dest : stdout;
+   if (settings->output_dest_stack_pos < 0)
+      result = (settings->initial_output_dest_changed) ? settings->alt_initial_output_dest : stdout;
    else
-      result = output_dest_stack[output_dest_stack_pos];
+      result = settings->output_dest_stack[settings->output_dest_stack_pos];
    return result;
 }
 
@@ -156,10 +199,11 @@ FILE * rpt_cur_output_dest() {
 /** Debugging function to show output destination.
  */
 void rpt_debug_output_dest() {
+    Per_Thread_Settings * settings = get_thread_settings();
     FILE * dest = rpt_cur_output_dest();
     char * addl = (dest == stdout) ? " (stdout)" : "";
     printf("(%s) output_dest_stack[%d] = %p %s\n",
-          __func__, output_dest_stack_pos, dest, addl);
+          __func__, settings->output_dest_stack_pos, dest, addl);
 }
 
 /** Changes the current output destination, without saving
@@ -170,11 +214,12 @@ void rpt_debug_output_dest() {
  * @remark Needed for set_fout() in core.c
  */
 void rpt_change_output_dest(FILE* new_dest) {
-   if (output_dest_stack_pos >= 0)
-      output_dest_stack[output_dest_stack_pos] = new_dest;
+   Per_Thread_Settings * settings = get_thread_settings();
+   if (settings->output_dest_stack_pos >= 0)
+      settings->output_dest_stack[settings->output_dest_stack_pos] = new_dest;
    else {
-      initial_output_dest_changed = true;
-      alt_initial_output_dest = new_dest;
+      settings->initial_output_dest_changed = true;
+      settings->alt_initial_output_dest = new_dest;
    }
 }
 
@@ -203,7 +248,7 @@ void rpt_nl() {
  *
  * @remark This is the core function through which all output is funneled.
  */
-void rpt_title(char * title, int depth) {
+void rpt_title(const char * title, int depth) {
    bool debug = false;
    if (debug)
       printf("(%s) Writing to %p\n", __func__, rpt_cur_output_dest());
@@ -227,7 +272,7 @@ void rpt_title(char * title, int depth) {
  * used along with #rpt_vstring() because the different position of the
  * **depth** parameter makes the code harder to read.
  */
-void rpt_label(int depth, char * text) {
+void rpt_label(int depth, const char * text) {
    rpt_title(text, depth);
 }
 
@@ -340,6 +385,7 @@ void rpt_2col(char * s1,  char * s2,  int col2offset, bool offset_absolute, int
    rpt_vstring(depth, "%-*s%s", col1sz, s1, s2 );
 }
 
+
 /* Reports the contents of a file.
  *
  * @param   fn        name of file
@@ -348,6 +394,7 @@ void rpt_2col(char * s1,  char * s2,  int col2offset, bool offset_absolute, int
  */
 int rpt_file_contents(const char * fn, bool verbose, int depth) {
    GPtrArray * line_array = g_ptr_array_new();
+   g_ptr_array_set_free_func(line_array, g_free);
    int rc = file_getlines(fn, line_array, false);
    if (rc < 0) {
       if (verbose)
@@ -365,6 +412,7 @@ int rpt_file_contents(const char * fn, bool verbose, int depth) {
          rpt_title(curline, depth);
       }
    }
+   g_ptr_array_free(line_array, true);
    return rc;
 }
 
@@ -447,6 +495,27 @@ void rpt_int(char * name, char * info, int val, int depth) {
    rpt_str(name, info, buf, depth);
 }
 
+/** Writes a string to the current output destination, describing a named unsigned integer value.
+ *
+ * The output is indented per the specified indentation depth.
+ *
+ * Optionally, a description string can be specified along with the name.
+ * The description string will be surrounded by parentheses.
+ *
+ * The value is prefixed with a colon.
+ *
+ * @param name  name of value
+ * @param info  if non-null, description of value
+ * @param val   unsigned integer value
+ * @param depth logical indentation depth
+ */
+void rpt_unsigned(char * name, char * info, int val, int depth) {
+   char buf[10];
+   snprintf(buf, 9, "%u", val);
+   rpt_str(name, info, buf, depth);
+}
+
+
 
 /** Writes a string to the current output destination describing a 4 byte integer value,
  * indented per the specified indentation depth.
