@@ -1,30 +1,10 @@
-/* string_util.h
- *
- * <copyright>
- * Copyright (C) 2014-2018 Sanford Rockowitz <rockowitz@minsoft.com>
- *
- * Licensed under the GNU General Public License Version 2
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
- * </endcopyright>
- */
-
 /** @file string_util.h
  *  String utility functions header file
  */
 
+// Copyright (C) 2014-2019 Sanford Rockowitz <rockowitz@minsoft.com>
+// SPDX-License-Identifier: GPL-2.0-or-later
+
 #ifndef STRINGUTIL_H_
 #define STRINGUTIL_H_
 
@@ -121,13 +101,11 @@ Null_Terminated_String_Array g_ptr_array_to_ntsa(GPtrArray * garray, bool duplic
 
 
 //
-// Integer conversion
+// Numeric conversion
 //
 
 bool str_to_int(const char * sval, int * p_ival, int base);
-#ifdef OLD
-bool str_to_int_old(const char * nptr, int * ival);
-#endif
+bool str_to_float(const char * sval, float * p_fval);
 
 
 //
@@ -137,11 +115,6 @@ bool str_to_int_old(const char * nptr, int * ival);
 bool hhs_to_byte_in_buf(const char * s,  Byte * result);    // converts null terminated string into buffer
 bool any_one_byte_hex_string_to_byte_in_buf(const char * s, Byte * result);
 bool hhc_to_byte_in_buf(const char * hh, Byte * result);    // converts 2 characters at hh into buffer
-#ifdef OLD
-Byte hhs_to_byte(char * s);                           // converts null terminated string
-Byte hhc_to_byte(char * hh);                          // converts 2 characters at hh
-void test_hhs_to_byte() ;
-#endif
 int  hhs_to_byte_array(const char * hhs, Byte** pBa);
 
 char * hexstring(const Byte * bytes, int size);  // buffer returned must be freed
@@ -155,13 +128,6 @@ char * hexstring2(
           bool                  uppercase,  // use upper case hex characters
           char *                buffer,     // buffer in which to return hex string
           int                   bufsz);     // buffer size
-#ifdef DEPRECATED
-char * hexstring2_t(
-          const unsigned char * bytes,      // bytes to convert
-          int                   len,        // number of bytes
-          const char *          sepstr,     // separator string between hex digits
-          bool                  uppercase); // use upper case hex characters?
-#endif
 char * hexstring3_t(
           const unsigned char * bytes,      // bytes to convert
           int                   len,        // number of bytes
