@@ -1,36 +1,20 @@
-/* sysfs_util.c
- *
- * <copyright>
- * Copyright (C) 2014-2017 Sanford Rockowitz <rockowitz@minsoft.com>
- *
- * Licensed under the GNU General Public License Version 2
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
- * </endcopyright>
- */
+/** @file sysfs_util.c
+  *
+  * Functions for reading /sys file system
+  */
 
-/** \file
- * Functions for reading /sys file system
- */
+// Copyright (C) 2016-2019 Sanford Rockowitz <rockowitz@minsoft.com>
+// SPDX-License-Identifier: GPL-2.0-or-later
 
+//* \cond */
 #include <assert.h>
+#include <errno.h>
 #include <limits.h>
 #include <sys/stat.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+/** \endcond */
 
 #include "file_util.h"
 #include "string_util.h"
@@ -163,10 +147,9 @@ is_module_loaded_using_sysfs(
 }
 
 
-// The following functions would more properly be located in a file in base,
-// as they are not really generic sysfs utilities, but in the interest of
-// not proliferating files they are included here.
-
+// The following functions are not really generic sysfs utilities, and more
+// properly belong in a file in subdirectory base, but to avoid yet more file
+// proliferation are included here.
 
 /** Gets the sysfs name of an I2C device,
  *  i.e. the value of /sys/bus/in2c/devices/i2c-n/name
@@ -178,7 +161,8 @@ is_module_loaded_using_sysfs(
  *  \remark
  *  Caller is responsible for freeing returned value
  */
-char * get_i2c_device_sysfs_name(int busno) {
+char *
+get_i2c_device_sysfs_name(int busno) {
    char workbuf[50];
    snprintf(workbuf, 50, "/sys/bus/i2c/devices/i2c-%d/name", busno);
    char * name = file_get_first_line(workbuf, /*verbose */ false);
@@ -186,6 +170,45 @@ char * get_i2c_device_sysfs_name(int busno) {
    return name;
 }
 
+
+/** Gets the driver name of an I2C device,
+ *  i.e. the basename of /sys/bus/i2c/devices/i2c-n/device/driver/module
+ *
+ *  \param  busno   I2C bus number
+ *  \return newly allocated string containing driver name
+ *          NULL if not found
+ *
+ *  \remark
+ *  Caller is responsible for freeing returned value
+ */
+static char *
+get_i2c_device_sysfs_driver(int busno) {
+   char * driver_name = NULL;
+   char workbuf[100];
+   snprintf(workbuf, 100, "/sys/bus/i2c/devices/i2c-%d/device/driver/module", busno);
+
+   char resolved_path[PATH_MAX];
+   char * rpath = realpath(workbuf, resolved_path);
+   // printf("(%s) rpath=|%s|\n", __func__, rpath);
+   if (!rpath) {
+      int errsv = errno;
+      if (errsv == ENOENT) {
+         // Path does not exist for amdgpu driver, nouveau on kernel 4.0 (SuSe Lean 42), perhaps others
+      }
+      else {
+         printf("(%s) realpath(%s) returned NULL, errno=%d", __func__, workbuf, errsv);
+      }
+   }
+   else {
+      // printf("realpath returned %s\n", rpath);
+      // printf("%s --> %s\n",workfn, resolved_path);
+      driver_name = g_path_get_basename(rpath);
+   }
+   // printf("(%s) busno=%d, returning %s\n", __func__, busno, driver_name);
+   return driver_name;
+}
+
+
 #ifdef UNUSED
 static bool is_smbus_device_using_sysfs(int busno) {
 #ifdef OLD
@@ -205,33 +228,32 @@ static bool is_smbus_device_using_sysfs(int busno) {
 #endif
 
 
-bool ignorable_i2c_device_sysfs_name(const char * name) {
+static bool
+ignorable_i2c_device_sysfs_name(const char * name, const char * driver) {
    bool result = false;
    const char * ignorable_prefixes[] = {
          "SMBus",
-         "soc:i2cdsi",
+         "Synopsys DesignWare",
+         "soc:i2cdsi",   // Raspberry Pi
          "smu",          // Mac G5, probing causes system hang
          "mac-io",       // Mac G5
          "u4",           // Mac G5
          NULL };
    if (name) {
-#ifdef OLD
-      if (str_starts_with(name, "SMBus"))
-         result = true;
-      else if (streq(name, "soc:i2cdsi"))     // Raspberry Pi
-         result = true;
-#endif
       if (starts_with_any(name, ignorable_prefixes) >= 0)
          result = true;
-
+      else if (streq(driver, "nouveau")) {
+         if ( !str_starts_with(name, "nvkm-") ) {
+            result = true;
+            // printf("(%s) name=|%s|, driver=|%s| - Ignore\n", __func__, name, driver);
+         }
+      }
    }
-   // printf("(%s) name=|%s|, returning: %s\n", __func__, name, bool_repr(result));
+   // printf("(%s) name=|%s|, driver=|%s|, returning: %s\n", __func__, name, driver, sbool(result));
    return result;
 }
 
 
-
-
 /** Checks if an I2C bus cannot be a DDC/CI connected monitor
  *  and therefore can be ignored, e.g. if it is an SMBus device.
  *
@@ -242,16 +264,17 @@ bool ignorable_i2c_device_sysfs_name(const char * name) {
  *  This function avoids unnecessary calls to i2cdetect, which can be
  *  slow for SMBus devices and fills the system logs with errors
  */
-bool is_ignorable_i2c_device(int busno) {
+bool
+is_ignorable_i2c_device(int busno) {
    bool result = false;
    char * name = get_i2c_device_sysfs_name(busno);
+   char * driver = get_i2c_device_sysfs_driver(busno);
    if (name)
-      result = ignorable_i2c_device_sysfs_name(name);
+      result = ignorable_i2c_device_sysfs_name(name, driver);
 
    // printf("(%s) busno=%d, name=|%s|, returning: %s\n", __func__, busno, name, bool_repr(result));
-   free(name);   // safe if NULL
+   free(name);    // safe if NULL
+   free(driver);  // ditto
    return result;
 }
 
-
-
