@@ -1,32 +1,10 @@
-/* ddc_capabilities.c
- *
- * Parse the capabilities string
- *
- * <copyright>
- * Copyright (C) 2014-2018 Sanford Rockowitz <rockowitz@minsoft.com>
- *
- * Licensed under the GNU General Public License Version 2
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
- * </endcopyright>
- */
-
-/** \file
+/** @file parse_capabilities.c
  *  Parse the capabilities string returned by DDC, query the parsed data structure.
  */
 
+// Copyright (C) 2014-2018 Sanford Rockowitz <rockowitz@minsoft.com>
+// SPDX-License-Identifier: GPL-2.0-or-later
+
 /** \cond */
 #include <assert.h>
 #include <glib.h>
@@ -60,86 +38,6 @@ char* test_cap_strings[] = {
 #endif
 
 
-//
-// Report parsed data structures
-//
-
-static void report_commands(Byte_Value_Array cmd_ids, int depth) {
-   rpt_label(depth, "Commands:");
-   int ct = bva_length(cmd_ids);
-   int ndx = 0;
-   for (; ndx < ct; ndx++) {
-      Byte hval = bva_get(cmd_ids, ndx);
-      rpt_vstring(depth+1, "Command: %02x (%s)", hval, ddc_cmd_code_name(hval));
-   }
-}
-
-
-static void report_features(
-      GPtrArray*             features,     // GPtrArray of Capabilities_Feature_Record
-      DDCA_MCCS_Version_Spec vcp_version)
-{
-   bool debug = false;
-   int d0 = 0;
-   int d1 = 1;
-
-   rpt_label(d0, "VCP Features:");
-   int ct = features->len;
-   int ndx;
-   for (ndx=0; ndx < ct; ndx++) {
-      Capabilities_Feature_Record * vfr = g_ptr_array_index(features, ndx);
-      DBGMSF(debug, "vfr = %p", vfr);
-      report_capabilities_feature(vfr, vcp_version, d1);
-   }
-}
-
-
-/** Reports the Parsed_Capabilities struct for human consumption.
- *
- * @param pcaps pointer to ***Parsed_Capabilities***
- *
- * Output is written to the current FOUT device.
- */
-void report_parsed_capabilities(Parsed_Capabilities* pcaps)
-{
-   bool debug = false;
-   assert(pcaps && memcmp(pcaps->marker, PARSED_CAPABILITIES_MARKER, 4) == 0);
-   DBGMSF(debug, "Starting. pcaps->raw_cmds_segment_seen=%s, pcaps->commands=%p, pcaps->vcp_features=%p",
-          bool_repr(pcaps->raw_cmds_segment_seen), pcaps->commands, pcaps->vcp_features);
-
-   int d0 = 0;
-   // int d1 = d0+1;
-   DDCA_Output_Level output_level = get_output_level();
-   if (output_level >= DDCA_OL_VERBOSE) {
-      rpt_vstring(d0, "%s capabilities string: %s",
-                      (pcaps->raw_value_synthesized) ? "Synthesized unparsed" : "Unparsed",
-                      pcaps->raw_value);
-   }
-   bool damaged = false;
-   rpt_vstring(d0, "MCCS version: %s",
-                   (pcaps->mccs_version_string) ? pcaps->mccs_version_string : "not present");
-
-   if (pcaps->commands)
-      report_commands(pcaps->commands, d0);
-   else {
-      // not an error in the case of USB_IO, as the capabilities string was
-      // synthesized and does not include a commands segment
-      // also, HP LP2480zx does not have cmds segment
-      if (pcaps->raw_cmds_segment_seen)
-         damaged = true;
-   }
-   if (pcaps->vcp_features)
-      report_features(pcaps->vcp_features, pcaps->parsed_mccs_version);
-   else {
-      // handle pathological case of 0 length capabilities string, e.g. Samsung S32D850T
-      if (pcaps->raw_vcp_features_seen)
-         damaged = true;
-   }
-   if (damaged)
-      rpt_label(d0, "Capabilities string not completely parsed");
-}
-
-
 //
 // Lifecycle
 //
@@ -170,6 +68,7 @@ Parsed_Capabilities * new_parsed_capabilities(
 {
    bool debug = false;
    DBGMSF(debug, "raw_cmds_segment_seen=%s, commands=%p", bool_repr(raw_cmds_segment_seen), commands);
+
    Parsed_Capabilities* pcaps = calloc(1, sizeof(Parsed_Capabilities));
    memcpy(pcaps->marker, PARSED_CAPABILITIES_MARKER, 4);
    pcaps->raw_value             = raw_value;
@@ -178,7 +77,7 @@ Parsed_Capabilities * new_parsed_capabilities(
    pcaps->commands              = commands;
    pcaps->vcp_features          = vcp_features;
 
-   DDCA_MCCS_Version_Spec parsed_vcp_version = {0.0};
+   DDCA_MCCS_Version_Spec parsed_vcp_version = DDCA_VSPEC_UNKNOWN;    // {0.0};
    if (mccs_ver) {
       int vmajor;
       int vminor;
@@ -194,6 +93,7 @@ Parsed_Capabilities * new_parsed_capabilities(
    }
    pcaps->parsed_mccs_version = parsed_vcp_version;
 
+   DBGMSF(debug, "Returning: %p", pcaps);
    return pcaps;
 }
 
@@ -325,14 +225,14 @@ static Byte_Value_Array parse_cmds_segment(
    Byte_Value_Array cmd_ids2 = bva_create();
    bool ok = store_bytehex_list(start, len, cmd_ids2, bva_appender);
    if (!ok) {
-      f0printf(FERR, "Error processing commands list: %.*s\n", len, start);
+      f0printf(ferr(), "Error processing commands list: %.*s\n", len, start);
    }
    // report_id_array(cmd_ids, "Command ids found:");
-   if (debug) {
-      // report_cmd_array(cmd_ids);
-      DBGMSG("store_bytehex_list returned %d", ok);
-      report_commands(cmd_ids2, 1);
-   }
+   // if (debug) {
+   //    // report_cmd_array(cmd_ids);
+   //    DBGMSG("store_bytehex_list returned %d", ok);
+   //    report_commands(cmd_ids2, 1);
+   // }
    Byte_Value_Array result = (ok) ? cmd_ids2 : NULL;
    DBGMSF(debug, "returning %p", result);
    return result;
@@ -421,7 +321,7 @@ static GPtrArray * parse_vcp_segment(
          }
       }
       if (!value_ok) {
-         f0printf(FOUT, "Feature: %.*s (invalid code)\n", 1, st);
+         f0printf(ferr(), "Feature: %.*s (invalid code)\n", 1, st);
       }
 
       if (*pos == '(') {
@@ -443,10 +343,10 @@ static GPtrArray * parse_vcp_segment(
       if (valid_feature) {
          Capabilities_Feature_Record * vfr =
                new_capabilities_feature(cur_feature_id, value_start, value_len);
-         if (debug) {
-            DDCA_MCCS_Version_Spec dummy_version = {0,0};
-            report_capabilities_feature(vfr, dummy_version, 1);
-         }
+         // if (debug) {
+         //    DDCA_MCCS_Version_Spec dummy_version = {0,0};
+         //    report_capabilities_feature(vfr, dummy_version, 1);
+         // }
          g_ptr_array_add(vcp_array, vfr);
       }
    }
@@ -610,7 +510,7 @@ Byte_Bit_Flags parsed_capabilities_feature_ids(
             VCP_Feature_Table_Entry * vfte = vcp_find_feature_by_hexid_w_default(frec->feature_id);
             if (!is_feature_readable_by_vcp_version(vfte, pcaps->parsed_mccs_version))
                add_feature_to_list = false;
-            if (vfte->vcp_global_flags & DDCA_SYNTHETIC)
+            if (vfte->vcp_global_flags & DDCA_SYNTHETIC_VCP_FEATURE_TABLE_ENTRY)
                free_synthetic_vcp_entry(vfte);
          }
          if (add_feature_to_list)
