@@ -1,49 +1,62 @@
-/* vcp_feature_codes.h
+/** @file vcp_feature_codes.h
  *
- * Contains tables describing VCP feature codes, and functions to interpret
- * those tables.
- *
- * <copyright>
- * Copyright (C) 2014-2017 Sanford Rockowitz <rockowitz@minsoft.com>
- *
- * Licensed under the GNU General Public License Version 2
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
- * </endcopyright>
+ *  Tables describing VCP feature codes and functions to interpret those tables
  */
 
-/** \f
- *  VCP Feature Code Table and related functions
- */
+// Copyright (C) 2014-2018 Sanford Rockowitz <rockowitz@minsoft.com>
+// SPDX-License-Identifier: GPL-2.0-or-later
 
 #ifndef VCP_FEATURE_CODES_H_
 #define VCP_FEATURE_CODES_H_
 
+/** \cond */
 #include <stdio.h>
 
+#include "util/data_structures.h"
+#include "util/string_util.h"
+/** \endcond */
+
 #include "public/ddcutil_types.h"
 
-#include "util/string_util.h"
-
 #include "base/core.h"
+#include "base/displays.h"
 #include "base/ddc_packets.h"
 #include "base/feature_sets.h"
+#include "base/feature_metadata.h"
 
 #include "vcp/vcp_feature_values.h"
 
 
+bool default_table_feature_detail_function(
+        Buffer *                data,
+        DDCA_MCCS_Version_Spec  vcp_version,
+        char**                  presult);
+bool format_feature_detail_debug_continuous(
+        Nontable_Vcp_Value *    code_info,
+        DDCA_MCCS_Version_Spec  vcp_version,
+        char *                  buffer,
+        int                     bufsz);
+bool format_feature_detail_debug_bytes(
+        Nontable_Vcp_Value *    code_info,
+        DDCA_MCCS_Version_Spec  vcp_version,
+        char *                  buffer,
+        int bufsz);
+bool format_feature_detail_standard_continuous(
+        Nontable_Vcp_Value *    code_info,
+        DDCA_MCCS_Version_Spec  vcp_version,
+        char *                  buffer,
+        int                     bufsz);
+bool format_feature_detail_sl_lookup(
+        Nontable_Vcp_Value *    code_info,
+        DDCA_MCCS_Version_Spec  vcp_version,
+        char *                  buffer,
+        int                     bufsz);
+bool format_feature_detail_sl_byte(
+        Nontable_Vcp_Value *     code_info,
+        DDCA_MCCS_Version_Spec   vcp_version,
+        char *                   buffer,
+        int                      bufsz);
+
 //
 // VCP Feature Interpretation
 //
@@ -57,8 +70,6 @@
 // xdf: VCP Version:
 //    NC, uses both high and low bytes
 
-
-
 // MCCS specification group to which feature belongs
 // Note a function can appear in multiple groups, e.g. in different spec versions
 // Should probably have been made version specific, but it's not worth redoing
@@ -83,7 +94,7 @@ typedef enum {
 // #define MCCS_V22          0x10
 
 
-
+#ifdef MOVED_TO_FEATURE_METADATA
 typedef
 bool (*Format_Normal_Feature_Detail_Function) (
           Nontable_Vcp_Value*     code_info,
@@ -91,13 +102,21 @@ bool (*Format_Normal_Feature_Detail_Function) (
           char *                  buffer,
           int                     bufsz);
 
+typedef
+bool (*Format_Normal_Feature_Detail_Function2) (
+          Nontable_Vcp_Value*        code_info,
+       // Display_Ref *              dref,
+       // DDCA_MCCS_Version_Spec     vcp_version,
+          DDCA_Feature_Value_Entry * sl_values,
+          char *                     buffer,
+          int                        bufsz);
+
 typedef
 bool (*Format_Table_Feature_Detail_Function) (
           Buffer *                data_bytes,
           DDCA_MCCS_Version_Spec  vcp_version,
           char **                 p_result_buffer);
-
-
+#endif
 
 extern DDCA_Feature_Value_Entry * pxc8_display_controller_type_values;
 
@@ -118,6 +137,7 @@ struct {
    char *                                desc;
    Format_Normal_Feature_Detail_Function nontable_formatter;
    Format_Table_Feature_Detail_Function  table_formatter;
+   // Format_Normal_Feature_Detail_Function2 dynamic_nc_formatter;   // only set for synthetic, udf features
    DDCA_Global_Feature_Flags             vcp_global_flags;
    ushort                                vcp_spec_groups;
    VCP_Feature_Subset                    vcp_subsets;
@@ -135,6 +155,7 @@ struct {
    DDCA_Feature_Value_Entry *            v22_sl_values;
 } VCP_Feature_Table_Entry;
 
+void dbgrpt_vcp_entry(VCP_Feature_Table_Entry * pfte, int depth);
 
 //
 // Functions that return or destroy a VCP_Feature_Table_Entry
@@ -147,6 +168,13 @@ free_synthetic_vcp_entry(
 VCP_Feature_Table_Entry *
 vcp_get_feature_table_entry(int ndx);
 
+#ifdef UNUSED
+VCP_Feature_Table_Entry *
+vcp_create_dynamic_feature(
+      DDCA_Vcp_Feature_Code   id,
+      DDCA_Feature_Metadata * dynamic_metadata);
+#endif
+
 VCP_Feature_Table_Entry *
 vcp_create_dummy_feature_for_hexid(
       DDCA_Vcp_Feature_Code id);
@@ -195,11 +223,10 @@ is_feature_writable_by_vcp_version(
       DDCA_MCCS_Version_Spec     vcp_version);
 
 bool
-is_feature_table_by_vcp_version(
+is_table_feature_by_vcp_version(
       VCP_Feature_Table_Entry *  vfte,
       DDCA_MCCS_Version_Spec     vcp_version);
 
-
 DDCA_Version_Feature_Flags
 get_version_specific_feature_flags(
       VCP_Feature_Table_Entry *  vfte,
@@ -226,7 +253,6 @@ get_version_sensitive_feature_name(
       VCP_Feature_Table_Entry * vfte,
       DDCA_MCCS_Version_Spec    vcp_version);
 
-
 char *
 get_version_specific_feature_name(
       VCP_Feature_Table_Entry * vfte,
@@ -236,57 +262,49 @@ char *
 get_non_version_specific_feature_name(
        VCP_Feature_Table_Entry * pvft_entry);
 
+Display_Feature_Metadata *
+extract_version_feature_info_from_feature_table_entry(
+      VCP_Feature_Table_Entry *  vfte,
+      DDCA_MCCS_Version_Spec     vspec,
+      bool                       version_sensitive);
+
 //
 // Functions that query the feature table by VCP feature code
 //
 
 char*
 get_feature_name_by_id_only(
-      DDCA_Vcp_Feature_Code           feature_code);
+      DDCA_Vcp_Feature_Code      feature_code);
 
 char*
 get_feature_name_by_id_and_vcp_version(
-      DDCA_Vcp_Feature_Code           feature_code,
+      DDCA_Vcp_Feature_Code      feature_code,
       DDCA_MCCS_Version_Spec     vspec);
 
-#ifdef OLD
-DDCA_Version_Feature_Info *
-get_version_specific_feature_info(
-      DDCA_Vcp_Feature_Code           feature_code,
-      bool                       with_default,
-      // DDCT_MCCS_Version_Spec  vspec,
-      DDCA_MCCS_Version_Id       mccs_version_id);
+Display_Feature_Metadata *
+get_version_feature_info_by_version_id_dfm(
+      DDCA_Vcp_Feature_Code   feature_code,
+      DDCA_MCCS_Version_Id    mccs_version_id,
+      bool                    with_default,
+      bool                    version_sensitive);
 
+Display_Feature_Metadata *
+get_version_feature_info_by_vspec_dfm(
+      DDCA_Vcp_Feature_Code   feature_code,
+      DDCA_MCCS_Version_Spec  vspec,
+      bool                    with_default,
+      bool                    version_sensitive);
 
-DDCA_Version_Feature_Info *
-get_version_sensitive_feature_info(
-      DDCA_Vcp_Feature_Code       feature_code,
-      bool                   with_default,
-   // DDCT_MCCS_Version_Spec vspec,
-      DDCA_MCCS_Version_Id   mccs_version_id);
-#endif
-
-DDCA_Version_Feature_Info *
-get_version_feature_info(
-      DDCA_Vcp_Feature_Code       feature_code,
-      DDCA_MCCS_Version_Id   mccs_version_id,
-      bool                   with_default,
-      bool                   version_sensitive);
-
-void
-free_version_feature_info(
-      DDCA_Version_Feature_Info * info);
-
-
-DDCA_Feature_Value_Entry *
-find_feature_values(
-      DDCA_Vcp_Feature_Code       feature_code,
-      DDCA_MCCS_Version_Spec vcp_version);
+// not used externally
+// DDCA_Feature_Value_Entry *
+// find_feature_value_table(
+//       DDCA_Vcp_Feature_Code   feature_code,
+//       DDCA_MCCS_Version_Spec  vcp_version);
 
 DDCA_Feature_Value_Entry *
 find_feature_values_for_capabilities(
-      DDCA_Vcp_Feature_Code       feature_code,
-      DDCA_MCCS_Version_Spec vcp_version);
+      DDCA_Vcp_Feature_Code   feature_code,
+      DDCA_MCCS_Version_Spec  vcp_version);
 
 //
 // Report Functions
@@ -297,37 +315,37 @@ report_vcp_feature_table_entry(
       VCP_Feature_Table_Entry * vfte,
       int                       depth);
 
-void report_version_feature_info(
-      DDCA_Version_Feature_Info * info, int depth);
-
 void
 vcp_list_feature_codes(FILE * fh);
 
-
 //
 // Miscellaneous Functions
 //
 
-
-char *
-get_feature_value_name(
-      DDCA_Feature_Value_Entry * value_entries,
-      Byte                       value_id);
-
-
 bool
 vcp_format_feature_detail(
        VCP_Feature_Table_Entry * vcp_entry,
        DDCA_MCCS_Version_Spec    vcp_version,
-       DDCA_Single_Vcp_Value *        valrec,
+       DDCA_Any_Vcp_Value *      valrec,
        char * *                  aformatted_data
      );
 
 int
 vcp_get_feature_code_count();
 
-
 void
 init_vcp_feature_codes();
 
+char *
+vcp_interpret_version_feature_flags(
+      DDCA_Version_Feature_Flags flags,
+      char *                     buf,
+      int                        bufsz);
+
+char *
+vcp_interpret_global_feature_flags(
+      DDCA_Global_Feature_Flags flags,
+      char *                    buf,
+      int                       bufsz);
+
 #endif /* VCP_FEATURE_CODES_H_ */
