@@ -54,6 +54,7 @@ void free_vcp_feature_set(VCP_Feature_Set * pset) {
 }
 
 
+#ifdef OLD
 VCP_Feature_Set *
 create_feature_set0(
       VCP_Feature_Subset   subset_id,
@@ -71,7 +72,7 @@ create_feature_set0(
    DBGTRC(debug, TRACE_GROUP, "Returning %p", fset);
    return fset;
 }
-
+#endif
 
 
 /** Given a feature set id for a named feature set (i.e. other than
@@ -118,9 +119,9 @@ create_feature_set(
    memcpy(fset->marker, VCP_FEATURE_SET_MARKER, 4);
    fset->subset = subset_id;
 
-   fset->members = g_ptr_array_sized_new(30);
+   fset->members = g_ptr_array_sized_new(250);
    if (subset_id == VCP_SUBSET_SCAN || subset_id == VCP_SUBSET_MFG) {
-      int ndx = 0;
+      int ndx = 1;
       if (subset_id == VCP_SUBSET_MFG)
          ndx = 0xe0;
       for (; ndx < 256; ndx++) {
@@ -136,10 +137,14 @@ create_feature_set(
                     exclude_table_features  )
                   showit = false;
             }
+            if (!is_feature_readable_by_vcp_version(vcp_entry, vcp_version)) {
+               showit = false;
+            }
             if (showit) {
                g_ptr_array_add(fset->members, vcp_entry);
             }
          }
+
          else {  // unknown feature or manufacturer specific feature
             g_ptr_array_add(fset->members, vcp_create_dummy_feature_for_hexid(id));
             if (ndx >= 0xe0 && (get_output_level() >= DDCA_OL_VERBOSE && !exclude_table_features) ) {
