@@ -1,25 +1,7 @@
-/* vcp_feature_values.h
- *
- * <copyright>
- * Copyright (C) 2014-2017 Sanford Rockowitz <rockowitz@minsoft.com>
- *
- * Licensed under the GNU General Public License Version 2
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
- * </endcopyright>
- */
+// vcp_feature_values.h
+
+// Copyright (C) 2014-2019 Sanford Rockowitz <rockowitz@minsoft.com>
+// SPDX-License-Identifier: GPL-2.0-or-later
 
 #ifndef VCP_FEATURE_VALUES_H_
 #define VCP_FEATURE_VALUES_H_
@@ -32,10 +14,11 @@
 #include "util/data_structures.h"
 
 #include "base/ddc_packets.h"
+#include "base/feature_metadata.h"
 
+#ifdef SINGLE_VCP_VALUE
 
 // Removed from API due to complexity.  Used only internally.
-// TODO: replace with DDCA_Any_Vcp_Value
 /** Represents a single VCP value of any type */
 typedef struct {
    DDCA_Vcp_Feature_Code  opcode;         /**< VCP feature code */
@@ -68,77 +51,48 @@ typedef struct {
    }       val;
 } Single_Vcp_Value;
 
+#endif
+
 
 char * vcp_value_type_name(DDCA_Vcp_Value_Type value_type);
+char * vcp_value_type_id(DDCA_Vcp_Value_Type  value_type);
 
 
-Single_Vcp_Value *
-create_nontable_vcp_value(
-      Byte     feature_code,
-      Byte     mh,
-      Byte     ml,
-      Byte     sh,
-      Byte     sl);
-
-#ifdef ALT
 DDCA_Any_Vcp_Value *
-create_nontable_vcp_value2(
+create_nontable_vcp_value(
       Byte feature_code,
       Byte mh,
       Byte ml,
       Byte sh,
       Byte sl);
-#endif
 
-Single_Vcp_Value *
+DDCA_Any_Vcp_Value *
 create_cont_vcp_value(
       Byte     feature_code,
       ushort   max_val,
       ushort   cur_val);
 
-Single_Vcp_Value *
-create_table_vcp_value_by_bytes(
-      Byte     feature_code,
-      Byte *   bytes,
-      ushort   bytect);
-
-#ifdef ALT
 DDCA_Any_Vcp_Value *
-create_table_vcp_value_by_bytes2(
+create_table_vcp_value_by_bytes(
       Byte   feature_code,
       Byte * bytes,
       ushort bytect);
-#endif
 
-Single_Vcp_Value *
+DDCA_Any_Vcp_Value *
 create_table_vcp_value_by_buffer(
       Byte     feature_code,
       Buffer*  buffer);
 
-#ifdef ALT
 DDCA_Any_Vcp_Value *
-create_table_vcp_value_by_buffer2(
-      Byte     feature_code,
-      Buffer*  buffer);
-#endif
-
-Single_Vcp_Value *
 create_single_vcp_value_by_parsed_vcp_response(
       Byte feature_id,
       Parsed_Vcp_Response * presp);
 
 Parsed_Vcp_Response *
 single_vcp_value_to_parsed_vcp_response(
-      Single_Vcp_Value * valrec);
-
-DDCA_Any_Vcp_Value *
-single_vcp_value_to_any_vcp_value(
-      Single_Vcp_Value * valrec);
-
-Single_Vcp_Value *
-any_vcp_value_to_single_vcp_value(
-      DDCA_Any_Vcp_Value * anyval);
+            DDCA_Any_Vcp_Value * valrec);
 
+#ifdef MOVED_TO_FEATURE_METADATA
 // Simple stripped-down version of Parsed_Nontable_Vcp_Response
 // for use within vcp_feature_codes.c
 
@@ -153,36 +107,38 @@ struct {
    Byte   sh;
    Byte   sl;
 } Nontable_Vcp_Value;
+#endif
 
+Nontable_Vcp_Value *
+      single_vcp_value_to_nontable_vcp_value(
+                               DDCA_Any_Vcp_Value * valrec);
+void  free_single_vcp_value(   DDCA_Any_Vcp_Value * vcp_value);
+void  dbgrpt_single_vcp_value( DDCA_Any_Vcp_Value * valrec, int depth);
 
-Nontable_Vcp_Value * single_vcp_value_to_nontable_vcp_value(Single_Vcp_Value * valrec);
-
-void free_single_vcp_value(Single_Vcp_Value * vcp_value);
-
-
-void dbgrpt_single_vcp_value(Single_Vcp_Value * valrec, int depth);
-void report_single_vcp_value(     Single_Vcp_Value * valrec, int depth);
-void report_any_vcp_value(DDCA_Any_Vcp_Value * valrec, int depth);
+// void report_any_vcp_value(DDCA_Any_Vcp_Value * valrec, int depth);
 
 
 extern const int summzrize_single_vcp_value_buffer_size;
-char * summarize_single_vcp_value_r(Single_Vcp_Value * valrec, char * buffer, int bufsz);
-char * summarize_single_vcp_value(Single_Vcp_Value * valrec);
+char * summarize_single_vcp_value_r(DDCA_Any_Vcp_Value * valrec, char * buffer, int bufsz);
+char * summarize_single_vcp_value(DDCA_Any_Vcp_Value * valrec);
 
 
+// Vcp_Value_Set declarations
+
 typedef GPtrArray *  Vcp_Value_Set;   // GPtrArray of DDCA_Single_Vcp_Value
 
 Vcp_Value_Set vcp_value_set_new(int initial_size);
 
 void free_vcp_value_set(Vcp_Value_Set vset);
 
-void vcp_value_set_add(Vcp_Value_Set vset,  Single_Vcp_Value * pval);
+void vcp_value_set_add(Vcp_Value_Set vset,
+      DDCA_Any_Vcp_Value * pval);
 
 int vcp_value_set_size(Vcp_Value_Set vset);
 
-Single_Vcp_Value * vcp_value_set_get(Vcp_Value_Set vset, int ndx);
+DDCA_Any_Vcp_Value *
+vcp_value_set_get(Vcp_Value_Set vset, int ndx);
 
-
-void report_vcp_value_set(Vcp_Value_Set vset, int depth);
+void dbgrpt_vcp_value_set(Vcp_Value_Set vset, int depth);
 
 #endif /* SRC_VCP_VCP_FEATURE_VALUES_H_ */
